searchData={"items":[{"type":"behaviour","title":"Cldr.Calendar","doc":"Calendar functions for calendars compatible with\nElixir's `Calendar` behaviour.\n\n`Cldr.Calendar` supports the creation of calendars\nthat are variations on the proleptic Cldr.Calendar.Gregorian\ncalendar. It also adds additional functions, defined\nby the `Cldr.Calendar` behaviour, to support these\nderived calendars.\n\nThe common purpose of these derived calendars is\nto support the creation and use of financial year\ncalendars that are commonly used in business.\n\nThere are two general types of calendars supported:\n\n* `month` calendars that mirror the monthly structure\n  of the proleptic `Cldr.Calendar.Gregorian` calendar but which are\n  deemed to start the year in a month other than January.\n\n* `week` calendars that are defined to have a 52 week\n  structure (53 weeks in a long year). These calendars\n  can be configured to start or end on the first, last or\n  nearest day to the beginning or end of a Cldr.Calendar.Gregorian\n  month.  The main intent behind this structure is to\n  have each year start and end on the same day of the\n  week with a consistent 13-week quarterly structure than\n  enables a more straight forware comparison with\n  same-period-last-year financial performance.","ref":"Cldr.Calendar.html"},{"type":"type","title":"Cldr.Calendar.any_date_time/0","doc":"Super type of any date or time","ref":"Cldr.Calendar.html#t:any_date_time/0"},{"type":"type","title":"Cldr.Calendar.calendar/0","doc":"Specifies the type of a calendar.\n\nA calendar is a module that implements\nthe `Calendar` and `Cldr.Calendar`\nbehaviours. Calendar functions will\ndefault to `Cldr.Calendar.Gregorian`\nin most cases.","ref":"Cldr.Calendar.html#t:calendar/0"},{"type":"callback","title":"Cldr.Calendar.calendar_base/0","doc":"Returns the calendar basis.\n\nReturns either :week or :month","ref":"Cldr.Calendar.html#c:calendar_base/0"},{"type":"function","title":"Cldr.Calendar.calendar_for_locale/2","doc":"Returns a calendar configured according to\nthe preferences defined for a locale.","ref":"Cldr.Calendar.html#calendar_for_locale/2"},{"type":"function","title":"Cldr.Calendar.calendar_for_territory/2","doc":"Returns a calendar configured according to\nthe preferences defined for a territory.","ref":"Cldr.Calendar.html#calendar_for_territory/2"},{"type":"function","title":"Cldr.Calendar.calendar_from_locale/1","doc":"Return the calendar module for a locale.","ref":"Cldr.Calendar.html#calendar_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Calendar.calendar_from_locale/1","doc":"* `:locale` is any locale or locale name validated\n  by `Cldr.validate_locale/2`.  The default is\n  `Cldr.get_locale()` which returns the locale\n  set for the current process.","ref":"Cldr.Calendar.html#calendar_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.calendar_from_locale/1","doc":"* `{:ok, calendar_module}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Calendar.html#calendar_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.calendar_from_locale/1","doc":"iex> Cldr.Calendar.calendar_from_locale \"en-US\"\n    {:ok, Cldr.Calendar.US}\n\n    iex> Cldr.Calendar.calendar_from_locale \"en-GB-u-ca-gregory\"\n    {:ok, Cldr.Calendar.Gregorian}\n\n    iex> Cldr.Calendar.calendar_from_locale \"fa-IR\"\n    {:ok, Cldr.Calendar.Persian}\n\n    iex> Cldr.Calendar.calendar_from_locale \"fa-IR-u-ca-gregory\"\n    {:ok, Cldr.Calendar.Gregorian}","ref":"Cldr.Calendar.html#calendar_from_locale/1-examples"},{"type":"function","title":"Cldr.Calendar.calendar_from_locale/2","doc":"","ref":"Cldr.Calendar.html#calendar_from_locale/2"},{"type":"function","title":"Cldr.Calendar.calendar_from_territory/1","doc":"Returns the calendar module preferred for\na territory.","ref":"Cldr.Calendar.html#calendar_from_territory/1"},{"type":"function","title":"Arguments - Cldr.Calendar.calendar_from_territory/1","doc":"* `territory` is any valid ISO3166-2 code as\n  an `t:String.t/0` or upcased `atom`.","ref":"Cldr.Calendar.html#calendar_from_territory/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.calendar_from_territory/1","doc":"* `{:ok, calendar_module}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Calendar.html#calendar_from_territory/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.calendar_from_territory/1","doc":"iex> Cldr.Calendar.calendar_from_territory :US\n    {:ok, Cldr.Calendar.US}\n\n    iex> Cldr.Calendar.calendar_from_territory :YY\n    {:error, {Cldr.UnknownTerritoryError, \"The territory :YY is unknown\"}}","ref":"Cldr.Calendar.html#calendar_from_territory/1-examples"},{"type":"function","title":"Notes - Cldr.Calendar.calendar_from_territory/1","doc":"The overwhelming majority of territories have\n`:gregorian` as their first preferred calendar\nand therefore `Cldr.Calendar.Gregorian` or\na derivation of it will be returned for most\nterritories.\n\nReturning any other calendar module would require:\n\n1. That another calendar is preferred over `:gregorian`\n   for a territory\n\n2. That a calendar module is available to support\n   that calendar.\n\nAs an example, Iran (territory `:IR`) prefers the\n`:persian` calendar. If the optional library\n[ex_cldr_calendars_persian](https://hex.pm/packages/ex_cldr_calendars_persian)\nis installed, the calendar module `Cldr.Calendar.Persian` will\nbe returned. If it is not installed, `Cldr.Calendar.Gregorian`\nwill be returned as `:gregorian` is the second preference\nfor `:IR`.","ref":"Cldr.Calendar.html#calendar_from_territory/1-notes"},{"type":"function","title":"Cldr.Calendar.calendar_module?/1","doc":"Returns a boolean indicating if a module\nis a `Cldr.Calendar` module","ref":"Cldr.Calendar.html#calendar_module?/1"},{"type":"type","title":"Cldr.Calendar.calendar_type/0","doc":"Specifies the type of a calendar","ref":"Cldr.Calendar.html#t:calendar_type/0"},{"type":"function","title":"Cldr.Calendar.calendar_year/1","doc":"Returns the `year` number for\na `date` that is the representation\nused for a calendar.\n\nThe calendar year may be different the\nthe year in the struct. The struct year\nis designed for convertability and for\ndate/time arithmetic.\n\nThe representation in rendered calendar\nmay be different. For example, in the Chinese\ncalendar the cardinal year since epoch is\nstored in the struct but the calendar\nyear used for representation is the\nsexigesimal year (a number between 1 and 60).","ref":"Cldr.Calendar.html#calendar_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.calendar_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#calendar_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.calendar_year/1","doc":"* the calendar year as an\n  integer.","ref":"Cldr.Calendar.html#calendar_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.calendar_year/1","doc":"iex> Cldr.Calendar.calendar_year ~D[2019-01-01]\n    2019\n\n    iex> Cldr.Calendar.calendar_year Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    2019\n\n    iex> Cldr.Calendar.calendar_year Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    2019","ref":"Cldr.Calendar.html#calendar_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.calendar_year/3","doc":"Returns a the year in a calendar year.","ref":"Cldr.Calendar.html#c:calendar_year/3"},{"type":"callback","title":"Cldr.Calendar.cldr_calendar_type/0","doc":"Returns the CLDR calendar type.\n\nOnly algorithmic calendars are considered\nin this implementation","ref":"Cldr.Calendar.html#c:cldr_calendar_type/0"},{"type":"function","title":"Cldr.Calendar.current/2","doc":"Returns the current date or date range for\na date period (year, quarter, month, week\nor day).","ref":"Cldr.Calendar.html#current/2"},{"type":"function","title":"Arguments - Cldr.Calendar.current/2","doc":"* `date_or_date_range` is any `t:Date.t/0` or\n  `Date.Range.t`.\n\n* `period` is `:year`, `:quarter`, `:month`,\n  `:week` or `:day`.","ref":"Cldr.Calendar.html#current/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.current/2","doc":"When a `t:Date.t/0` is passed, a `t:Date.t/0` is\nreturned.  When a `Date.Range.t` is passed\na `Date.Range.t` is returned.","ref":"Cldr.Calendar.html#current/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.current/2","doc":"iex> Cldr.Calendar.current ~D[2019-01-01], :day\n    ~D[2019-01-01]","ref":"Cldr.Calendar.html#current/2-examples"},{"type":"function","title":"Cldr.Calendar.cyclic_year/1","doc":"Returns the cycle `year`\nnumber for a `date`.\n\nA related gregorian year is the gregorian\nyear that is most closely associated with a\ndate that is in another calendar.","ref":"Cldr.Calendar.html#cyclic_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.cyclic_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#cyclic_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.cyclic_year/1","doc":"* the cyclic year as an integer.","ref":"Cldr.Calendar.html#cyclic_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.cyclic_year/1","doc":"iex> Cldr.Calendar.cyclic_year ~D[2019-01-01]\n    2019\n\n    iex> Cldr.Calendar.cyclic_year Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    2019\n\n    iex> Cldr.Calendar.cyclic_year Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    2019","ref":"Cldr.Calendar.html#cyclic_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.cyclic_year/3","doc":"Returns a the cyclic year in a calendar year.","ref":"Cldr.Calendar.html#c:cyclic_year/3"},{"type":"type","title":"Cldr.Calendar.date/0","doc":"All date fields are optional however many functions\nwill require the presence of one or more - and\noften all - fields be present.","ref":"Cldr.Calendar.html#t:date/0"},{"type":"function","title":"Cldr.Calendar.date_from_day_of_year/3","doc":"Returns a `t:Date.t/0` from a year, day_of_year\nand a calendar.","ref":"Cldr.Calendar.html#date_from_day_of_year/3"},{"type":"function","title":"Arguments - Cldr.Calendar.date_from_day_of_year/3","doc":"* `year` is any integer year that is valid in\n  `calendar`.\n\n* `day_of_year` is any valid ordinal day of\n  `year`.\n\n* `calendar` is any module implementing\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.html#date_from_day_of_year/3-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.date_from_day_of_year/3","doc":"* a `t:Date.t/0` or\n\n* `{:error, :invalid_date}`","ref":"Cldr.Calendar.html#date_from_day_of_year/3-returns"},{"type":"function","title":"Cldr.Calendar.date_from_iso_days/2","doc":"Returns a date represented by a number of\ndays since the start of the epoch.\n\nThe start of the epoch is the date\n`0000-01-01`.","ref":"Cldr.Calendar.html#date_from_iso_days/2"},{"type":"function","title":"Argumenets - Cldr.Calendar.date_from_iso_days/2","doc":"* `iso_days` is an integer representing the\n  number of days since the start of the epoch.\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar` behaviours.","ref":"Cldr.Calendar.html#date_from_iso_days/2-argumenets"},{"type":"function","title":"Returns - Cldr.Calendar.date_from_iso_days/2","doc":"* a `t:Date.t/0`","ref":"Cldr.Calendar.html#date_from_iso_days/2-returns"},{"type":"function","title":"Example - Cldr.Calendar.date_from_iso_days/2","doc":"iex> Cldr.Calendar.date_from_iso_days 737425, Calendar.ISO\n    ~D[2019-01-01]\n\n    iex> Cldr.Calendar.date_from_iso_days 366, Calendar.ISO\n    ~D[0001-01-01]\n\n    iex> Cldr.Calendar.date_from_iso_days 0, Calendar.ISO\n    ~D[0000-01-01]","ref":"Cldr.Calendar.html#date_from_iso_days/2-example"},{"type":"function","title":"Cldr.Calendar.date_from_list/2","doc":"Returns a `t:Date.t/0` from a keyword list\nand a calendar.","ref":"Cldr.Calendar.html#date_from_list/2"},{"type":"function","title":"Arguments - Cldr.Calendar.date_from_list/2","doc":"* `[year: year, month: month, day: day}` is a\n  keyword list representing a date.\n\n* `calendar` is any module implementing\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.html#date_from_list/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.date_from_list/2","doc":"* a `t:Date.t/0` or\n\n* `{:error, :invalid_date}`","ref":"Cldr.Calendar.html#date_from_list/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.date_from_list/2","doc":"iex> Cldr.Calendar.date_from_list [year: 2019, month: 3, day: 25], Cldr.Calendar.Gregorian\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 25, month: 3, year: 2019}\n\n    iex> Cldr.Calendar.date_from_list [year: 2019, month: 2, day: 29], Cldr.Calendar.Gregorian\n    {:error, :invalid_date}","ref":"Cldr.Calendar.html#date_from_list/2-examples"},{"type":"function","title":"Cldr.Calendar.date_from_tuple/2","doc":"Returns a `t:Date.t/0` from a date tuple of\n`{year, month, day}` and a calendar.","ref":"Cldr.Calendar.html#date_from_tuple/2"},{"type":"function","title":"Arguments - Cldr.Calendar.date_from_tuple/2","doc":"* `{year, month, day}` is a tuple\n  representing a date.\n\n* `calendar` is any module implementing\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.html#date_from_tuple/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.date_from_tuple/2","doc":"* a `t:Date.t/0`.","ref":"Cldr.Calendar.html#date_from_tuple/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.date_from_tuple/2","doc":"iex> Cldr.Calendar.date_from_tuple {2019, 3, 25}, Cldr.Calendar.Gregorian\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 25, month: 3, year: 2019}\n\n    iex> Cldr.Calendar.date_from_tuple {2019, 2, 29}, Cldr.Calendar.Gregorian\n    {:error, :invalid_date}","ref":"Cldr.Calendar.html#date_from_tuple/2-examples"},{"type":"type","title":"Cldr.Calendar.date_time/0","doc":"All date time fields are optional however many functions\nwill require the presence of one or more - and\noften all - fields be present.","ref":"Cldr.Calendar.html#t:date_time/0"},{"type":"function","title":"Cldr.Calendar.date_to_iso_days/1","doc":"Returns the number of days since the start\nof the epoch.\n\nThe start of the epoch is the date 0000-01-01.","ref":"Cldr.Calendar.html#date_to_iso_days/1"},{"type":"function","title":"Argumenets - Cldr.Calendar.date_to_iso_days/1","doc":"* `date` is any `t:Date.t/0`.","ref":"Cldr.Calendar.html#date_to_iso_days/1-argumenets"},{"type":"function","title":"Returns - Cldr.Calendar.date_to_iso_days/1","doc":"* The integer number of days since the epoch\n  for the given `date`.","ref":"Cldr.Calendar.html#date_to_iso_days/1-returns"},{"type":"function","title":"Example - Cldr.Calendar.date_to_iso_days/1","doc":"iex> Cldr.Calendar.date_to_iso_days ~D[2019-01-01]\n    737425\n\n    iex> Cldr.Calendar.date_to_iso_days ~D[0001-01-01]\n    366\n\n    iex> Cldr.Calendar.date_to_iso_days ~D[0000-01-01]\n    0","ref":"Cldr.Calendar.html#date_to_iso_days/1-example"},{"type":"function","title":"Cldr.Calendar.date_to_string/1","doc":"Formats a date into a string representation.\n\nNote that the output is not decorated with\nthe calendar module name.","ref":"Cldr.Calendar.html#date_to_string/1"},{"type":"function","title":"Example - Cldr.Calendar.date_to_string/1","doc":"iex> Cldr.Calendar.date_to_string ~D[2019-12-04]\n    \"2019-12-04\"\n\n    iex> Cldr.Calendar.date_to_string ~D[2019-23-04 Cldr.Calendar.NRF]\n    \"2019-W23-4\"","ref":"Cldr.Calendar.html#date_to_string/1-example"},{"type":"function","title":"Cldr.Calendar.datetime_from_modified_julian_date/1","doc":"Returns the DateTime (defaulting to UTC timezone)\nfor the given Modified Julian Day.","ref":"Cldr.Calendar.html#datetime_from_modified_julian_date/1"},{"type":"function","title":"Arguments - Cldr.Calendar.datetime_from_modified_julian_date/1","doc":"* `mjd` is a number representing days passed since November 17, 1858 (Julian Calendar)","ref":"Cldr.Calendar.html#datetime_from_modified_julian_date/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.datetime_from_modified_julian_date/1","doc":"* a `t:DateTime.t/0` at UTC timezone.","ref":"Cldr.Calendar.html#datetime_from_modified_julian_date/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.datetime_from_modified_julian_date/1","doc":"iex> Cldr.Calendar.datetime_from_modified_julian_date(59848)\n    ~U[2022-09-26 00:00:00.000Z]\n\n    iex> Cldr.Calendar.datetime_from_modified_julian_date(59848.75)\n    ~U[2022-09-26 18:00:00.000Z]","ref":"Cldr.Calendar.html#datetime_from_modified_julian_date/1-examples"},{"type":"type","title":"Cldr.Calendar.day/0","doc":"Specifies the day of a date as either\na positive integer or nil.","ref":"Cldr.Calendar.html#t:day/0"},{"type":"function","title":"Cldr.Calendar.day_of_era/1","doc":"Returns the `{day_of_era, era}` for\na `date`.","ref":"Cldr.Calendar.html#day_of_era/1"},{"type":"function","title":"Arguments - Cldr.Calendar.day_of_era/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#day_of_era/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.day_of_era/1","doc":"* a the days since the start of the era and\n  the era of the year as a tuple.","ref":"Cldr.Calendar.html#day_of_era/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.day_of_era/1","doc":"iex> Cldr.Calendar.day_of_era ~D[2019-01-01]\n    {737060, 1}\n\n    iex> Cldr.Calendar.day_of_era Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    {737093, 1}\n\n    iex> Cldr.Calendar.day_of_era Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    {737456, 1}","ref":"Cldr.Calendar.html#day_of_era/1-examples"},{"type":"type","title":"Cldr.Calendar.day_of_week/0","doc":"Specifies the days of the week as integers.\n\nDays of the week are encoded as the integers `1` through\n`7` with `1` representig Monday and 7 representing Sunday.\n\nNote that a calendar can be configured to start\non any day of the week. `day_of_week` is only a\nway of encoding the days as an integer.","ref":"Cldr.Calendar.html#t:day_of_week/0"},{"type":"function","title":"Cldr.Calendar.day_of_week/1","doc":"","ref":"Cldr.Calendar.html#day_of_week/1"},{"type":"type","title":"Cldr.Calendar.day_of_week_to_binary/0","doc":"A mapping of a day of the week ordinal to the\nlocalized string of the name of that day.","ref":"Cldr.Calendar.html#t:day_of_week_to_binary/0"},{"type":"function","title":"Cldr.Calendar.day_of_year/1","doc":"Returns the `day` of the year\nfor a `date`.","ref":"Cldr.Calendar.html#day_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.day_of_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#day_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.day_of_year/1","doc":"* a the day of the year as an\n  integer","ref":"Cldr.Calendar.html#day_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.day_of_year/1","doc":"iex> Cldr.Calendar.day_of_year ~D[2019-01-01]\n    1\n\n    iex> Cldr.Calendar.day_of_year ~D[2016-12-31]\n    366\n\n    iex> Cldr.Calendar.day_of_year ~D[2019-12-31]\n    365\n\n    iex> Cldr.Calendar.day_of_year ~D[2019-52-07 Cldr.Calendar.NRF]\n    365\n\n    iex> Cldr.Calendar.day_of_year ~D[2012-53-07 Cldr.Calendar.NRF]\n    372","ref":"Cldr.Calendar.html#day_of_year/1-examples"},{"type":"function","title":"Cldr.Calendar.days_in_month/1","doc":"","ref":"Cldr.Calendar.html#days_in_month/1"},{"type":"callback","title":"Cldr.Calendar.days_in_month/1","doc":"Returns the number of days in a month (withoout a year)","ref":"Cldr.Calendar.html#c:days_in_month/1"},{"type":"callback","title":"Cldr.Calendar.days_in_year/1","doc":"Returns the number of days in a year","ref":"Cldr.Calendar.html#c:days_in_year/1"},{"type":"function","title":"Cldr.Calendar.default_calendar/0","doc":"Returns the default calendar.","ref":"Cldr.Calendar.html#default_calendar/0"},{"type":"type","title":"Cldr.Calendar.era/0","doc":"Specifies the year of a date as either\na positive integer or nil.","ref":"Cldr.Calendar.html#t:era/0"},{"type":"function","title":"Cldr.Calendar.extended_year/1","doc":"Returns the extended `year` number for\na `date`.","ref":"Cldr.Calendar.html#extended_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.extended_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#extended_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.extended_year/1","doc":"* the extended calendar year as an\n  integer.","ref":"Cldr.Calendar.html#extended_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.extended_year/1","doc":"iex> Cldr.Calendar.extended_year ~D[2019-01-01]\n    2019\n\n    iex> Cldr.Calendar.extended_year Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    2019\n\n    iex> Cldr.Calendar.extended_year Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    2019","ref":"Cldr.Calendar.html#extended_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.extended_year/3","doc":"Returns a the extended year in a calendar year.","ref":"Cldr.Calendar.html#c:extended_year/3"},{"type":"function","title":"Cldr.Calendar.first_day_for_locale/1","doc":"Returns the first day of a week for a given\nlocale.\n\nNote that the first of the first week is commonly\nnot aligned with the first day of the year.","ref":"Cldr.Calendar.html#first_day_for_locale/1"},{"type":"function","title":"Cldr.Calendar.first_day_for_locale/2","doc":"","ref":"Cldr.Calendar.html#first_day_for_locale/2"},{"type":"function","title":"Cldr.Calendar.first_day_for_territory/1","doc":"","ref":"Cldr.Calendar.html#first_day_for_territory/1"},{"type":"function","title":"Cldr.Calendar.first_day_of_year/1","doc":"Returns the first date of a `year`\nfor a `t:Date.t/0`.","ref":"Cldr.Calendar.html#first_day_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.first_day_of_year/1","doc":"* `date` is any `t:Date.t/0`.","ref":"Cldr.Calendar.html#first_day_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.first_day_of_year/1","doc":"* a `t:Date.t/0`  or\n\n* `{:error, :invalid_date}`","ref":"Cldr.Calendar.html#first_day_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.first_day_of_year/1","doc":"iex>  Cldr.Calendar.first_day_of_year ~D[2019-12-01]\n    ~D[2019-01-01]","ref":"Cldr.Calendar.html#first_day_of_year/1-examples"},{"type":"function","title":"Cldr.Calendar.first_day_of_year/2","doc":"Returns the first date of a `year`\nin a `calendar`.","ref":"Cldr.Calendar.html#first_day_of_year/2"},{"type":"function","title":"Arguments - Cldr.Calendar.first_day_of_year/2","doc":"* `year` is any year.\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours.","ref":"Cldr.Calendar.html#first_day_of_year/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.first_day_of_year/2","doc":"* a `t:Date.t/0`  or\n\n* `{:error, :invalid_date}`","ref":"Cldr.Calendar.html#first_day_of_year/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.first_day_of_year/2","doc":"iex> Cldr.Calendar.first_day_of_year 2019, Cldr.Calendar.Gregorian\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 1, year: 2019}\n\n    iex> Cldr.Calendar.first_day_of_year 2019, Cldr.Calendar.NRF\n    %Date{calendar: Cldr.Calendar.NRF, day: 1, month: 1, year: 2019}","ref":"Cldr.Calendar.html#first_day_of_year/2-examples"},{"type":"function","title":"Cldr.Calendar.first_gregorian_day_of_year/1","doc":"Returns the gregorian date of the first day of of a `year`\nfor a `calendar`.","ref":"Cldr.Calendar.html#first_gregorian_day_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.first_gregorian_day_of_year/1","doc":"* `year` is any integer year number.\n\n* `calendar` is any module that implements the `Calendar` and\n  `Cldr.Calendar` behaviours or `Calendar.ISO`","ref":"Cldr.Calendar.html#first_gregorian_day_of_year/1-arguments"},{"type":"function","title":"Examples - Cldr.Calendar.first_gregorian_day_of_year/1","doc":"iex> Cldr.Calendar.first_gregorian_day_of_year 2019, Cldr.Calendar.Gregorian\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 1, year: 2019}\n\n    iex> Cldr.Calendar.first_gregorian_day_of_year 2019, Cldr.Calendar.NRF\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 3, month: 2, year: 2019}\n\n    iex> Cldr.Calendar.first_gregorian_day_of_year ~D[2019-12-01]\n    ~D[2019-01-01]","ref":"Cldr.Calendar.html#first_gregorian_day_of_year/1-examples"},{"type":"function","title":"Cldr.Calendar.first_gregorian_day_of_year/2","doc":"","ref":"Cldr.Calendar.html#first_gregorian_day_of_year/2"},{"type":"function","title":"Cldr.Calendar.friday/0","doc":"Returns the ordinal day number representing\nFriday.","ref":"Cldr.Calendar.html#friday/0"},{"type":"function","title":"Cldr.Calendar.inspect/2","doc":"An `inspect_fun/2` that can be configured in\n`Inspect.Opts` supporting inspection of user-defined\ncalendars.\n\nThis function can be configured in `IEx` for Elixir version 1.9\nand later by:\n\n    IEx.configure(inspect: [inspect_fun: &Cldr.Calendar.inspect/2])\n    :ok","ref":"Cldr.Calendar.html#inspect/2"},{"type":"function","title":"Cldr.Calendar.interval/3","doc":"Returns an `Enumerable` list of dates of a given precision\nof either `:years`, `:quarters`, `:months`, `:weeks` or\n`:days`.","ref":"Cldr.Calendar.html#interval/3"},{"type":"function","title":"Arguments - Cldr.Calendar.interval/3","doc":"* `date_from` is a any `t:Date.t/0` that is the start of the\n  sequence.\n\n* `date_to_or_count` is upper bound of the sequence\n  as a `t:Date.t/0` or the number of dates in the\n  sequence to be generated.\n\n* `precision` is one of `:years`, `:quarters`,\n  `:months`, `:weeks` or `:days`.\n\nThe sequence is generated starting with `date_from` until the next date\nin the sequence would be after `date_to`.","ref":"Cldr.Calendar.html#interval/3-arguments"},{"type":"function","title":"Notes - Cldr.Calendar.interval/3","doc":"The sequence can be in ascending or descending date order\nbased upon whether `date_from` is greater than `date_to`.","ref":"Cldr.Calendar.html#interval/3-notes"},{"type":"function","title":"Returns - Cldr.Calendar.interval/3","doc":"* A list of dates","ref":"Cldr.Calendar.html#interval/3-returns"},{"type":"function","title":"Examples - Cldr.Calendar.interval/3","doc":"iex> d = ~D[2019-01-31]\n    ~D[2019-01-31]\n    iex> d2 = ~D[2019-05-31]\n    ~D[2019-05-31]\n    iex> Cldr.Calendar.interval d, 3, :months\n    [~D[2019-01-31], ~D[2019-02-28], ~D[2019-03-31]]\n    iex> Cldr.Calendar.interval d, d2, :months\n    [~D[2019-01-31], ~D[2019-02-28], ~D[2019-03-31],\n     ~D[2019-04-30], ~D[2019-05-31]]","ref":"Cldr.Calendar.html#interval/3-examples"},{"type":"type","title":"Cldr.Calendar.interval_relation/0","doc":"The types of relationship between two Date.Range intervals","ref":"Cldr.Calendar.html#t:interval_relation/0"},{"type":"function","title":"Cldr.Calendar.interval_stream/3","doc":"Returns an a `Stream` function than can be lazily\nenumerated.\n\nThis function has the same arguments and provides\nthe same functionality as `interval/3` except that\nit is lazily evaluated.","ref":"Cldr.Calendar.html#interval_stream/3"},{"type":"function","title":"Arguments - Cldr.Calendar.interval_stream/3","doc":"* `date_from` is a any `t:Date.t/0` that is the start of the\n  sequence.\n\n* `date_to_or_count` is upper bound of the sequence\n  as a `t:Date.t/0` or the number of dates in the\n  sequence to be generated.\n\n* `precision` is one of `:years`, `:quarters`,\n  `:months`, `:weeks` or `:days`.\n\nThe sequence is generated starting with `date_from` until the next date\nin the sequence would be after `date_to`.","ref":"Cldr.Calendar.html#interval_stream/3-arguments"},{"type":"function","title":"Notes - Cldr.Calendar.interval_stream/3","doc":"The sequence can be in ascending or descending date order\nbased upon whether `date_from` is greater than `date_to`.","ref":"Cldr.Calendar.html#interval_stream/3-notes"},{"type":"function","title":"Returns - Cldr.Calendar.interval_stream/3","doc":"* A list of dates.","ref":"Cldr.Calendar.html#interval_stream/3-returns"},{"type":"function","title":"Examples - Cldr.Calendar.interval_stream/3","doc":"iex> d = ~D[2019-01-31]\n    ~D[2019-01-31]\n    iex> d2 = ~D[2019-05-31]\n    ~D[2019-05-31]\n    iex> Cldr.Calendar.interval_stream(d, 3, :months) |> Enum.to_list\n    [~D[2019-01-31], ~D[2019-02-28], ~D[2019-03-31]]\n    iex> Cldr.Calendar.interval_stream(d, d2, :months) |> Enum.to_list\n    [~D[2019-01-31], ~D[2019-02-28], ~D[2019-03-31],\n     ~D[2019-04-30], ~D[2019-05-31]]","ref":"Cldr.Calendar.html#interval_stream/3-examples"},{"type":"macro","title":"Cldr.Calendar.is_full_date/1","doc":"","ref":"Cldr.Calendar.html#is_full_date/1"},{"type":"type","title":"Cldr.Calendar.iso_day_number/0","doc":"Represents the number of days since the\ncalendar epoch.\n\nThe Calendar epoch is `0000-01-01`\nin the proleptic gregorian calendar.","ref":"Cldr.Calendar.html#t:iso_day_number/0"},{"type":"function","title":"Cldr.Calendar.iso_days_to_day_of_week/1","doc":"Returns the day of the week for a given\n`iso_day_number`","ref":"Cldr.Calendar.html#iso_days_to_day_of_week/1"},{"type":"function","title":"Arguments - Cldr.Calendar.iso_days_to_day_of_week/1","doc":"* `iso_day_number` is the number of days since the start\n  of the epoch.  See `Cldr.Calendar.date_to_iso_days/1`.","ref":"Cldr.Calendar.html#iso_days_to_day_of_week/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.iso_days_to_day_of_week/1","doc":"* An integer representing a day of the week where Monday\n  is represented by `1` and Sunday is represented by `7`.","ref":"Cldr.Calendar.html#iso_days_to_day_of_week/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.iso_days_to_day_of_week/1","doc":"iex> days = Cldr.Calendar.date_to_iso_days ~D[2019-01-01]\n    iex> Cldr.Calendar.iso_days_to_day_of_week(days) == Cldr.Calendar.tuesday()\n    true","ref":"Cldr.Calendar.html#iso_days_to_day_of_week/1-examples"},{"type":"function","title":"Cldr.Calendar.iso_week_of_year/1","doc":"Returns the `ISO week` number for\na `date`.","ref":"Cldr.Calendar.html#iso_week_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.iso_week_of_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#iso_week_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.iso_week_of_year/1","doc":"* a the ISO week of the year as an\n  integer or\n\n* `{:error, :not_defined}` is the calendar\n  does not support the concept of weeks.","ref":"Cldr.Calendar.html#iso_week_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.iso_week_of_year/1","doc":"iex> Cldr.Calendar.iso_week_of_year ~D[2019-01-01]\n    {2019, 1}\n    iex> Cldr.Calendar.iso_week_of_year ~D[2019-02-01]\n    {2019, 5}\n    iex> Cldr.Calendar.iso_week_of_year ~D[2019-52-01 Cldr.Calendar.NRF]\n    {2020, 4}\n    iex> Cldr.Calendar.iso_week_of_year ~D[2019-26-01 Cldr.Calendar.NRF]\n    {2019, 30}\n    iex> Cldr.Calendar.iso_week_of_year ~D[2019-12-01 Cldr.Calendar.Julian]\n    {:error, :not_defined}","ref":"Cldr.Calendar.html#iso_week_of_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.iso_week_of_year/3","doc":"Returns a tuple of `{year, week_in_year}` for a given `year`, `month` or `week`, and `day`\nfor a a calendar.\n\nThe `iso_week_of_year` is calculated based on the ISO calendar.","ref":"Cldr.Calendar.html#c:iso_week_of_year/3"},{"type":"function","title":"Cldr.Calendar.last_day_of_year/1","doc":"Returns the last date of a `year`\nfor a `t:Date.t/0`.","ref":"Cldr.Calendar.html#last_day_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.last_day_of_year/1","doc":"* `date` is any `t:Date.t/0`.","ref":"Cldr.Calendar.html#last_day_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.last_day_of_year/1","doc":"* a `t:Date.t/0`  or\n\n* `{:error, :invalid_date}`","ref":"Cldr.Calendar.html#last_day_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.last_day_of_year/1","doc":"iex>  Cldr.Calendar.last_day_of_year ~D[2019-01-01]\n    ~D[2019-12-31]","ref":"Cldr.Calendar.html#last_day_of_year/1-examples"},{"type":"function","title":"Cldr.Calendar.last_day_of_year/2","doc":"Returns the last date of a `year`\nfor a `calendar`.","ref":"Cldr.Calendar.html#last_day_of_year/2"},{"type":"function","title":"Arguments - Cldr.Calendar.last_day_of_year/2","doc":"* `year` is any year.\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours","ref":"Cldr.Calendar.html#last_day_of_year/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.last_day_of_year/2","doc":"* a `t:Date.t/0`  or\n\n* `{:error, :invalid_date}`","ref":"Cldr.Calendar.html#last_day_of_year/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.last_day_of_year/2","doc":"iex> Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.Gregorian)\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 12, year: 2019}\n\n    iex> Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    %Date{calendar: Cldr.Calendar.NRF, day: 7, month: 52, year: 2019}","ref":"Cldr.Calendar.html#last_day_of_year/2-examples"},{"type":"function","title":"Cldr.Calendar.last_gregorian_day_of_year/1","doc":"Returns the gregorian date of the first day of a `year`\nfor a `calendar`.","ref":"Cldr.Calendar.html#last_gregorian_day_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.last_gregorian_day_of_year/1","doc":"* `year` is any integer year number or a `t:date/0`.\n\n* `calendar` is any module that implements the `Calendar` and\n  `Cldr.Calendar` behaviours or `Calendar.ISO`.","ref":"Cldr.Calendar.html#last_gregorian_day_of_year/1-arguments"},{"type":"function","title":"Examples - Cldr.Calendar.last_gregorian_day_of_year/1","doc":"iex> Cldr.Calendar.last_gregorian_day_of_year 2019, Cldr.Calendar.Gregorian\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 12, year: 2019}\n\n    iex> Cldr.Calendar.last_gregorian_day_of_year 2019, Cldr.Calendar.NRF\n    %Date{calendar: Cldr.Calendar.Gregorian, day: 1, month: 2, year: 2020}\n\n    iex> Cldr.Calendar.last_gregorian_day_of_year ~D[2019-12-01]\n    ~D[2019-12-31]","ref":"Cldr.Calendar.html#last_gregorian_day_of_year/1-examples"},{"type":"function","title":"Cldr.Calendar.last_gregorian_day_of_year/2","doc":"","ref":"Cldr.Calendar.html#last_gregorian_day_of_year/2"},{"type":"type","title":"Cldr.Calendar.leap_month?/0","doc":"Boolean indicating is this is a leap month","ref":"Cldr.Calendar.html#t:leap_month?/0"},{"type":"function","title":"Cldr.Calendar.localize/1","doc":"Localize a date by converting it to calendar\nintrospected from the provided or default locale.","ref":"Cldr.Calendar.html#localize/1"},{"type":"function","title":"Arguments - Cldr.Calendar.localize/1","doc":"* `date` is any `t:Date.t/0`.\n\n* `options` is a `t:Keyword.t/0` list of options. The default is\n  `[]`.","ref":"Cldr.Calendar.html#localize/1-arguments"},{"type":"function","title":"Options - Cldr.Calendar.localize/1","doc":"* `:locale` is any valid locale name in the list returned by\n  `Cldr.known_locale_names/1` or a `Cldr.LanguageTag` struct\n  returned by `Cldr.Locale.new!/2`. The default is `Cldr.get_locale()`.\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `default_backend!/0`.","ref":"Cldr.Calendar.html#localize/1-options"},{"type":"function","title":"Returns - Cldr.Calendar.localize/1","doc":"* `{:ok, date}` where `date` is converted into the calendar\n  associated with the current or provided locale.","ref":"Cldr.Calendar.html#localize/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.localize/1","doc":"iex> Cldr.Calendar.localize ~D[2022-06-09], locale: \"fr\"\n    {:ok, %Date{year: 2022, month: 6, day: 9, calendar: Cldr.Calendar.FR}}","ref":"Cldr.Calendar.html#localize/1-examples"},{"type":"function","title":"Cldr.Calendar.localize/2","doc":"","ref":"Cldr.Calendar.html#localize/2"},{"type":"function","title":"Cldr.Calendar.localize/3","doc":"Returns a localized string for a part of\na `t:Date.t/0`.","ref":"Cldr.Calendar.html#localize/3"},{"type":"function","title":"Arguments - Cldr.Calendar.localize/3","doc":"* `date` is any `t:Date.t/0`.\n\n* `part` is one of `:era`, `:quarter`, `:month`,\n  `:day_of_week` or `:days_of_week`.\n\n* `options` is a `t:Keyword.t/0` list of options.","ref":"Cldr.Calendar.html#localize/3-arguments"},{"type":"function","title":"Options - Cldr.Calendar.localize/3","doc":"* `:locale` is any valid locale name in the list returned by\n  `Cldr.known_locale_names/1` or a `Cldr.LanguageTag` struct\n  returned by `Cldr.Locale.new!/2`. The default is `Cldr.get_locale()`.\n\n* `:backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `default_backend!/0`.\n\n* `:format` is one of `:wide`, `:abbreviated` or `:narrow`. The\n  default is `:abbreviated`.\n\n* `:era` will, if set to `:variant` will localize the era using\n  the variant data. In the `:en` locale, this will produce `CE` and\n  `BCE` rather than the default `AD` and `BC`.","ref":"Cldr.Calendar.html#localize/3-options"},{"type":"function","title":"Returns - Cldr.Calendar.localize/3","doc":"* A string representing the localized date part, or\n\n* A list of strings representing the days of the week for\n  when `part` is `:days_of_week`. The days are in week order for\n  the given date's calendar, or\n\n* `{error, {exception_module, message}}` if an error is detected","ref":"Cldr.Calendar.html#localize/3-returns"},{"type":"function","title":"Examples - Cldr.Calendar.localize/3","doc":"iex> Cldr.Calendar.localize ~D[2019-01-01], :era\n    \"AD\"\n\n    iex> Cldr.Calendar.localize ~D[2019-01-01], :era, era: :variant\n    \"CE\"\n\n    iex> Cldr.Calendar.localize ~D[2019-01-01], :day_of_week\n    \"Tue\"\n\n    iex> Cldr.Calendar.localize ~D[0001-01-01], :day_of_week\n    \"Mon\"\n\n    iex> Cldr.Calendar.localize ~D[2019-01-01], :days_of_week\n    [{1, \"Mon\"}, {2, \"Tue\"}, {3, \"Wed\"}, {4, \"Thu\"}, {5, \"Fri\"}, {6, \"Sat\"}, {7, \"Sun\"}]\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :era\n    \"AD\"\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :quarter\n    \"Q2\"\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :month\n    \"Jun\"\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week\n    \"Sat\"\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :wide\n    \"Saturday\"\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :narrow\n    \"S\"\n\n    iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, locale: \"ar\"\n    \"السبت\"","ref":"Cldr.Calendar.html#localize/3-examples"},{"type":"function","title":"Cldr.Calendar.min_days_for_locale/1","doc":"Returns the minimum days in the first week of a year\nfor a given locale.","ref":"Cldr.Calendar.html#min_days_for_locale/1"},{"type":"function","title":"Cldr.Calendar.min_days_for_locale/2","doc":"","ref":"Cldr.Calendar.html#min_days_for_locale/2"},{"type":"function","title":"Cldr.Calendar.min_days_for_territory/1","doc":"","ref":"Cldr.Calendar.html#min_days_for_territory/1"},{"type":"function","title":"Cldr.Calendar.minus/4","doc":"Decrements a date or date range by an\ninteger amount of a date period (year,\nquarter, month, week or day).","ref":"Cldr.Calendar.html#minus/4"},{"type":"function","title":"Arguments - Cldr.Calendar.minus/4","doc":"* `date_or_date_range` is any `t:Date.t/0` or\n  `Date.Range.t`\n\n* `period` is `:years`, `:quarters`, `:months`,\n  `:weeks` or `:days`.\n\n* `options` is a `t:Keyword.t/0` list of options.","ref":"Cldr.Calendar.html#minus/4-arguments"},{"type":"function","title":"Options - Cldr.Calendar.minus/4","doc":"* `:coerce` is a boolean which, when set to `true`\n  will coerce the month and/or day to be a valid date.\n  This affects,for example, moving to the previous month\n  from `~D[2019-03-31]`. Since there is no date `~D[2019-02-31]`\n  this would normally return `{:error, :invalid_date}`.\n  Setting `coerce: true` it will return `~D[2019-02-28]`.\n  `coerce: true` is the default.","ref":"Cldr.Calendar.html#minus/4-options"},{"type":"function","title":"Returns - Cldr.Calendar.minus/4","doc":"When a `t:Date.t/0` is passed, a `t:Date.t/0` is\nreturned.  When a `Date.Range.t` is passed\na `Date.Range.t` is returned.","ref":"Cldr.Calendar.html#minus/4-returns"},{"type":"function","title":"Examples - Cldr.Calendar.minus/4","doc":"iex> Cldr.Calendar.minus ~D[2016-03-01], :days, 1\n    ~D[2016-02-29]\n\n    iex> Cldr.Calendar.minus ~D[2019-03-01], :months, 1\n    ~D[2019-02-01]\n\n    iex> Cldr.Calendar.minus ~D[2016-03-01], :days, 1\n    ~D[2016-02-29]\n\n    iex> Cldr.Calendar.minus ~D[2019-03-01], :days, 1\n    ~D[2019-02-28]\n\n    iex> Cldr.Calendar.minus ~D[2019-03-01], :months, 1\n    ~D[2019-02-01]\n\n    iex> Cldr.Calendar.minus ~D[2019-03-01], :quarters, 1\n    ~D[2018-12-01]\n\n    iex> Cldr.Calendar.minus ~D[2019-03-01], :years, 1\n    ~D[2018-03-01]","ref":"Cldr.Calendar.html#minus/4-examples"},{"type":"function","title":"Cldr.Calendar.modified_julian_day/1","doc":"Returns the Modified Julian Day of\na `t:Date.t/0`.","ref":"Cldr.Calendar.html#modified_julian_day/1"},{"type":"function","title":"Arguments - Cldr.Calendar.modified_julian_day/1","doc":"* `date_or_datetime` is any `t:Date.t/0` or a `t:DateTime.t/0`.\n  If a `t:DateTime.t/0` is given, the result will be given in\n  the current timezone.","ref":"Cldr.Calendar.html#modified_julian_day/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.modified_julian_day/1","doc":"* an number representing the\n  Modified Julian Day of the `date`.","ref":"Cldr.Calendar.html#modified_julian_day/1-returns"},{"type":"function","title":"Notes - Cldr.Calendar.modified_julian_day/1","doc":"The Modified Julian Day is the number of days\nsince November 17, 1858. Therefore this function\nonly returns valid values for dates after this\ndate.","ref":"Cldr.Calendar.html#modified_julian_day/1-notes"},{"type":"function","title":"Examples - Cldr.Calendar.modified_julian_day/1","doc":"iex> Cldr.Calendar.modified_julian_day ~D[2019-01-01]\n    58484.0\n\n    iex> Cldr.Calendar.modified_julian_day ~U[2019-01-01 12:00:00Z]\n    58484.5\n\n    iex> Cldr.Calendar.modified_julian_day(~U[2022-09-26 18:00:00.000Z])\n    59848.75\n\n    # If the given DateTime is not UTC, the result is given in\n    # the local timezone\n\n    iex> dt = DateTime.shift_zone!(~U[2019-01-01 14:00:00Z], \"America/Sao_Paulo\")\n    #DateTime<2019-01-01 12:00:00-02:00 -02 America/Sao_Paulo>\n    iex> Cldr.Calendar.modified_julian_day(dt)\n    58484.5","ref":"Cldr.Calendar.html#modified_julian_day/1-examples"},{"type":"function","title":"Cldr.Calendar.monday/0","doc":"Returns the ordinal day number representing\nMonday","ref":"Cldr.Calendar.html#monday/0"},{"type":"type","title":"Cldr.Calendar.month/0","doc":"Specifies the month of a date as either\na positive integer or nil.","ref":"Cldr.Calendar.html#t:month/0"},{"type":"callback","title":"Cldr.Calendar.month/2","doc":"Returns a date range representing the days in a\ngiven month for a calendar year.","ref":"Cldr.Calendar.html#c:month/2"},{"type":"function","title":"Cldr.Calendar.month_of_year/1","doc":"Returns the `month` number for\na `date`.","ref":"Cldr.Calendar.html#month_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.month_of_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#month_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.month_of_year/1","doc":"* the month of the year as an\n  integer","ref":"Cldr.Calendar.html#month_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.month_of_year/1","doc":"iex> Cldr.Calendar.month_of_year ~D[2019-01-01]\n    1\n    iex> Cldr.Calendar.month_of_year ~D[2019-12-01]\n    12\n    iex> Cldr.Calendar.month_of_year ~D[2019-52-01 Cldr.Calendar.NRF]\n    12\n    iex> Cldr.Calendar.month_of_year ~D[2019-26-01 Cldr.Calendar.NRF]\n    6","ref":"Cldr.Calendar.html#month_of_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.month_of_year/3","doc":"Returns the `month` for a given `year`, `month` or `week`, and `day`\nfor a a calendar.\n\nThe `month_of_year` is calculated based upon the calendar configuration.","ref":"Cldr.Calendar.html#c:month_of_year/3"},{"type":"function","title":"Cldr.Calendar.months_in_year/1","doc":"","ref":"Cldr.Calendar.html#months_in_year/1"},{"type":"type","title":"Cldr.Calendar.naive_date_time/0","doc":"All naive date time fields are optional however many functions\nwill require the presence of one or more - and\noften all - fields be present.","ref":"Cldr.Calendar.html#t:naive_date_time/0"},{"type":"function","title":"Cldr.Calendar.new/3","doc":"Creates a new calendar based upon the provided configuration.\n\nIf a module exists with the `calendar_module` name then it\nis returned, not recreated.","ref":"Cldr.Calendar.html#new/3"},{"type":"function","title":"Arguments - Cldr.Calendar.new/3","doc":"* `calendar_module` is an atom representing the module\n  name of the created calendar.\n\n* `calendar_type` is an atom of either `:month` or\n  `:week` indicating which type of calendar is to\n  be created.\n\n* `config` is a Keyword list defining the configuration\n  of the calendar.","ref":"Cldr.Calendar.html#new/3-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.new/3","doc":"* `{:ok, module}` where `module` is the new calendar\n  module that conforms to the `Calendar` and `Cldr.Calendar`\n  behaviours or\n\n* `{:module_already_exists, module}` if a module of the given\n  calendar name already exists. It is not guaranteed\n  that the module is in fact a calendar module in this case.","ref":"Cldr.Calendar.html#new/3-returns"},{"type":"function","title":"Configuration options - Cldr.Calendar.new/3","doc":"The following options can be provided to create\na new calendar.\n\n* `:cldr_backend` defines a default\n  backend module to be used for this calendar.\n  The default is `nil`.\n\n* `:weeks_in_month` defines the layout of\n  weeks in a quarter for a week- or month-\n  based calendar. The value must be one of\n  `[4, 4, 5]`, `[4,5,4]` or `[5,4,4]`.\n  The default is `[4,4,5]`. This option\n  is ignored for `:month` based calendars\n  that have the parameter `day_of_year: :first`.\n\n* `:begins_or_ends` determines whether the calendar\n  year begins or ends on the given `:day_of_week` and\n  `:month_of_year`. The default is `:begins`.\n\n* `:first_or_last` determines whether the calendar\n  year starts (or ends) on the first, last or nearest\n  `:day-of_week` and `:month_of_year`. The default\n  is `:first`\n\n* `:day_of_week` determines the day\n  of the week on which this calendar begins\n  or ends. It may be a number in the range\n  `1..7` representing Monday to Sunday.\n  It may also be `:first` indicating the\n  the weeks are calculated from the first\n  day of the calendar day irrespective of\n  the day of the week. In this case the last\n  week of the year may be less than 7 days\n  in length. The default is `1`.\n\n* `:month_of_year` determines the Cldr.Calendar.Gregorian\n  month of year in which this calendar begins\n  or ends. The default is `1`.\n\n* `:year` is used to determine which calendar\n  Greogian year is applicable for a given\n  calendar date. The valid options are `:first`,\n  `:last` and `majority`.  The default is\n  `:majority`.\n\n* `:min_days_in_first_week` is used to determine\n  how many days of the Cldr.Calendar.Gregorian year must be in\n  the first week of a calendar year. This is used\n  when determining when the year starts for week-based\n  years.  The default is `4` which is consistent with\n  the [ISO Week calendar](https://en.wikipedia.org/wiki/ISO_week_date)","ref":"Cldr.Calendar.html#new/3-configuration-options"},{"type":"function","title":"Examples - Cldr.Calendar.new/3","doc":"Each calendar has a function `__config__/0` generated within\nit and therefore the configuration of the included calendars\nin `ex_cldr_calendars` provide insight into the behaviour\nof the configuration parameters.\n\nAs an example here we define the [ISO Week calendar](https://en.wikipedia.org/wiki/ISO_week_date)\ncalendar in full:\n\n```\ndefmodule ISOWeek do\n  use Cldr.Calendar.Base.Week,\n    day_of_week: 1,              # Weeks begin or end on Monday\n    month_of_year: 1,            # Years begin or end in January\n    min_days_in_first_week, 4,   # 4 Cldr.Calendar.Gregorian days of the year must be in the first week\n    begins_or_ends: :begins,     # The year *begins* on the `day_of_week` and `month_of_year`\n    first_or_last: :first,       # They year *begins* on the *first* `day_of_week` and `month_of_year`\n    weeks_in_month: [4, 4, 5],   # The weeks are laid out as *months* in a `[4,4,5]` pattern\n    year: :majority,             # Any given year is that in which the majority of Cldr.Calendar.Gregorian months fall\n    cldr_backend: nil,           # No default `cldr_backend` is configured.\n    locale: nil                  # No `locale` is used to aid configuration\nend\n```\n\nThis can be generated at runtime by:\n```\n    iex> Cldr.Calendar.new ISOWeek, :week,\n    ...>   day_of_week: 1,\n    ...>   month_of_year: 1,\n    ...>   min_days_in_first_week: 4,\n    ...>   begins_or_ends: :begins,\n    ...>   first_or_last: :first,\n    ...>   weeks_in_month: [4, 4, 5],\n    ...>   year: :majority,\n    ...>   cldr_backend: nil\n    {:ok, ISOWeek}\n```\nNote that `Cldr.Calendar.ISOWeek` is included as part of this\nlibrary.","ref":"Cldr.Calendar.html#new/3-examples"},{"type":"function","title":"Cldr.Calendar.next/3","doc":"Returns the next date or date range for\na date period (year, quarter, month, week\nor day).","ref":"Cldr.Calendar.html#next/3"},{"type":"function","title":"Arguments - Cldr.Calendar.next/3","doc":"* `date_or_date_range` is any `t:Date.t/0` or\n  `Date.Range.t`.\n\n* `period` is `:year`, `:quarter`, `:month`,\n` :week` or `:day`.","ref":"Cldr.Calendar.html#next/3-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.next/3","doc":"When a `t:Date.t/0` is passed, a `t:Date.t/0` is\nreturned.  When a `Date.Range.t` is passed\na `Date.Range.t` is returned.","ref":"Cldr.Calendar.html#next/3-returns"},{"type":"function","title":"Examples - Cldr.Calendar.next/3","doc":"iex> Cldr.Calendar.next ~D[2019-01-01], :day\n    ~D[2019-01-02]\n\n    iex> Cldr.Calendar.next ~D[2019-01-01], :month\n    ~D[2019-02-01]\n\n    iex> Cldr.Calendar.next ~D[2019-01-01], :quarter\n    ~D[2019-04-01]\n\n    iex> Cldr.Calendar.next ~D[2019-01-01], :year\n    ~D[2020-01-01]","ref":"Cldr.Calendar.html#next/3-examples"},{"type":"type","title":"Cldr.Calendar.part/0","doc":"The part of a date, time or datetime that can be\nlocalized.","ref":"Cldr.Calendar.html#t:part/0"},{"type":"callback","title":"Cldr.Calendar.periods_in_year/1","doc":"Returns the number of periods (which are\nmonths in a month calendar and weeks in a\nweek calendar) in a year","ref":"Cldr.Calendar.html#c:periods_in_year/1"},{"type":"function","title":"Cldr.Calendar.plus/2","doc":"Adds a duration to a date","ref":"Cldr.Calendar.html#plus/2"},{"type":"function","title":"Arguments - Cldr.Calendar.plus/2","doc":"* `date` is any map that conforms to\n  `t:Calendar.date.t/0`.\n\n* `duration` is any duration returned\n  by `Cldr.Calendar.Duration.new!/2`.\n\n* `options` is a Keyword list of\n  options.","ref":"Cldr.Calendar.html#plus/2-arguments"},{"type":"function","title":"Options - Cldr.Calendar.plus/2","doc":"* Options are those applicable to\n  `Cldr.Calendar.plus/4`.","ref":"Cldr.Calendar.html#plus/2-options"},{"type":"function","title":"Returns - Cldr.Calendar.plus/2","doc":"* A `t:Calendar.date.t/0` advanced by the duration.","ref":"Cldr.Calendar.html#plus/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.plus/2","doc":"iex> Cldr.Calendar.plus ~D[2020-01-01],\n    ...> Cldr.Calendar.Duration.new!(~D[2020-01-01], ~D[2020-02-01])\n    ~D[2020-02-01]\n\n    iex> Cldr.Calendar.plus ~D[2020-01-01],\n    ...> Cldr.Calendar.Duration.new!(~D[2020-01-01], ~D[2020-01-02])\n    ~D[2020-01-02]\n\n    iex> Cldr.Calendar.plus ~D[2020-01-01],\n    ...> Cldr.Calendar.Duration.new!(~D[2020-01-01], ~D[2020-02-01])\n    ~D[2020-02-01]\n\n    iex> Cldr.Calendar.plus ~D[2020-01-01],\n    ...> Cldr.Calendar.Duration.new!(~D[2020-01-01], ~D[2021-02-01])\n    ~D[2021-02-01]","ref":"Cldr.Calendar.html#plus/2-examples"},{"type":"function","title":"Cldr.Calendar.plus/3","doc":"","ref":"Cldr.Calendar.html#plus/3"},{"type":"function","title":"Cldr.Calendar.plus/4","doc":"Increments a date or date range by an\ninteger amount of a date period (year,\nquarter, month, week or day).","ref":"Cldr.Calendar.html#plus/4"},{"type":"function","title":"Arguments - Cldr.Calendar.plus/4","doc":"* `date_or_date_range` is any `t:Date.t/0` or\n  `Date.Range.t`.\n\n* `period` is `:years`, `:quarters`, `:months`,\n  `:weeks` or `:days`.\n\n* `options` is a `t:Keyword.t/0` list of options.","ref":"Cldr.Calendar.html#plus/4-arguments"},{"type":"function","title":"Options - Cldr.Calendar.plus/4","doc":"* `:coerce` is a boolean which, when set to `true`\n  will coerce the month and/or day to be a valid date.\n  This affects,for example, moving to the previous month\n  from `~D[2019-03-31]`. Since there is no date `~D[2019-02-31]`\n  this would normally return `{:error, :invalid_date}`.\n  Setting `coerce: true` it will return `~D[2019-02-28]`.\n  `coerce: true` is the default.","ref":"Cldr.Calendar.html#plus/4-options"},{"type":"function","title":"Returns - Cldr.Calendar.plus/4","doc":"When a `t:Date.t/0` is passed, a `t:Date.t/0` is\nreturned.  When a `Date.Range.t` is passed\na `Date.Range.t` is returned.","ref":"Cldr.Calendar.html#plus/4-returns"},{"type":"function","title":"Examples - Cldr.Calendar.plus/4","doc":"iex> Cldr.Calendar.plus ~D[2016-02-29], :days, 1\n    ~D[2016-03-01]\n\n    iex> Cldr.Calendar.plus ~D[2019-03-01], :months, 1\n    ~D[2019-04-01]\n\n    iex> Cldr.Calendar.plus ~D[2016-02-29], :days, 1\n    ~D[2016-03-01]\n\n    iex> Cldr.Calendar.plus ~D[2019-02-28], :days, 1\n    ~D[2019-03-01]\n\n    iex> Cldr.Calendar.plus ~D[2019-03-01], :months, 1\n    ~D[2019-04-01]\n\n    iex> Cldr.Calendar.plus ~D[2019-03-01], :quarters, 1\n    ~D[2019-06-01]\n\n    iex> Cldr.Calendar.plus ~D[2019-03-01], :years, 1\n    ~D[2020-03-01]","ref":"Cldr.Calendar.html#plus/4-examples"},{"type":"callback","title":"Cldr.Calendar.plus/6","doc":"Increments a `t:Date.t/0` or `Date.Range.t` by a specified positive\nor negative integer number of periods (year, quarter, month,\nweek or day).\n\nCalendars need only implement this callback for `:months` and `:quarters`\nsince all other date periods can be derived.","ref":"Cldr.Calendar.html#c:plus/6"},{"type":"type","title":"Cldr.Calendar.precision/0","doc":"The precision for date intervals","ref":"Cldr.Calendar.html#t:precision/0"},{"type":"function","title":"Cldr.Calendar.previous/3","doc":"Returns the previous date or date range for\na date period (year, quarter, month, week\nor day).","ref":"Cldr.Calendar.html#previous/3"},{"type":"function","title":"Arguments - Cldr.Calendar.previous/3","doc":"* `date_or_date_range` is any `t:Date.t/0` or\n  `Date.Range.t`.\n\n* `period` is `:year`, `:quarter`, `:month`,\n  `:week` or `:day`.\n\n* `options` is a `t:Keyword.t/0` list of options that is\n  passed to `plus/4` or `minus/4`.","ref":"Cldr.Calendar.html#previous/3-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.previous/3","doc":"When a `t:Date.t/0` is passed, a `t:Date.t/0` is\nreturned.  When a `Date.Range.t` is passed\na `Date.Range.t` is returned.","ref":"Cldr.Calendar.html#previous/3-returns"},{"type":"function","title":"Examples - Cldr.Calendar.previous/3","doc":"iex> Cldr.Calendar.previous ~D[2019-01-01], :day\n    ~D[2018-12-31]\n\n    iex> Cldr.Calendar.previous ~D[2019-01-01], :quarter\n    ~D[2018-10-01]\n\n    iex> Cldr.Calendar.previous ~D[2019-01-01], :month\n    ~D[2018-12-01]\n\n    iex> Cldr.Calendar.previous ~D[2019-01-01], :year\n    ~D[2018-01-01]","ref":"Cldr.Calendar.html#previous/3-examples"},{"type":"type","title":"Cldr.Calendar.quarter/0","doc":"Specifies the quarter of year for a calendar date.","ref":"Cldr.Calendar.html#t:quarter/0"},{"type":"callback","title":"Cldr.Calendar.quarter/2","doc":"Returns a date range representing the days in a\ngiven quarter for a calendar year.","ref":"Cldr.Calendar.html#c:quarter/2"},{"type":"function","title":"Cldr.Calendar.quarter_of_year/1","doc":"Returns the `quarter` number for\na `date`.","ref":"Cldr.Calendar.html#quarter_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.quarter_of_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#quarter_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.quarter_of_year/1","doc":"* a the quarter of the year as an\n  integer","ref":"Cldr.Calendar.html#quarter_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.quarter_of_year/1","doc":"iex> Cldr.Calendar.quarter_of_year ~D[2019-01-01]\n    1\n\n    iex> Cldr.Calendar.quarter_of_year Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    1\n\n    iex> Cldr.Calendar.quarter_of_year Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    4","ref":"Cldr.Calendar.html#quarter_of_year/1-examples"},{"type":"function","title":"Cldr.Calendar.related_gregorian_year/1","doc":"Returns the related gregorian `year`\nnumber for a `date`.\n\nA related gregorian year is the gregorian\nyear that is most closely associated with a\ndate that is in another calendar.","ref":"Cldr.Calendar.html#related_gregorian_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.related_gregorian_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#related_gregorian_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.related_gregorian_year/1","doc":"* the related gregorian year as an\n  integer.","ref":"Cldr.Calendar.html#related_gregorian_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.related_gregorian_year/1","doc":"iex> Cldr.Calendar.related_gregorian_year ~D[2019-01-01]\n    2019\n\n    iex> Cldr.Calendar.related_gregorian_year Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    2019\n\n    iex> Cldr.Calendar.related_gregorian_year Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    2019","ref":"Cldr.Calendar.html#related_gregorian_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.related_gregorian_year/3","doc":"Returns a the related year in a calendar year.","ref":"Cldr.Calendar.html#c:related_gregorian_year/3"},{"type":"function","title":"Cldr.Calendar.same_as_default?/1","doc":"","ref":"Cldr.Calendar.html#same_as_default?/1"},{"type":"function","title":"Cldr.Calendar.saturday/0","doc":"Returns the ordinal day number representing\nSaturday.","ref":"Cldr.Calendar.html#saturday/0"},{"type":"function","title":"Cldr.Calendar.sunday/0","doc":"Returns the ordinal day number representing\nSunday.","ref":"Cldr.Calendar.html#sunday/0"},{"type":"function","title":"Cldr.Calendar.thursday/0","doc":"Returns the ordinal day number representing\nThursday.","ref":"Cldr.Calendar.html#thursday/0"},{"type":"type","title":"Cldr.Calendar.time/0","doc":"All time fields are optional however many functions\nwill require the presence of one or more - and\noften all - fields be present.","ref":"Cldr.Calendar.html#t:time/0"},{"type":"function","title":"Cldr.Calendar.tuesday/0","doc":"Returns the ordinal day number representing\nTuesday.","ref":"Cldr.Calendar.html#tuesday/0"},{"type":"function","title":"Cldr.Calendar.validate_calendar/1","doc":"Validates if the argument is a Cldr.Calendar\ncalendar module.","ref":"Cldr.Calendar.html#validate_calendar/1"},{"type":"function","title":"Arguments - Cldr.Calendar.validate_calendar/1","doc":"* `calendar_module` is a module that implements the\n  `Cldr.Calendar` behaviour.","ref":"Cldr.Calendar.html#validate_calendar/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.validate_calendar/1","doc":"* `{:ok, calendar_module}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Calendar.html#validate_calendar/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.validate_calendar/1","doc":"iex> Cldr.Calendar.validate_calendar Cldr.Calendar.Gregorian\n    {:ok, Cldr.Calendar.Gregorian}\n\n    iex> Cldr.Calendar.validate_calendar :not_a_calendar\n    {:error,\n     {Cldr.InvalidCalendarModule, \":not_a_calendar is not a calendar module.\"}}","ref":"Cldr.Calendar.html#validate_calendar/1-examples"},{"type":"function","title":"Cldr.Calendar.wednesday/0","doc":"Returns the ordinal day number representing\nWednesday.","ref":"Cldr.Calendar.html#wednesday/0"},{"type":"type","title":"Cldr.Calendar.week/0","doc":"Specifies the week of year for a calendar date.","ref":"Cldr.Calendar.html#t:week/0"},{"type":"callback","title":"Cldr.Calendar.week/2","doc":"Returns a date range representing the days in a\ngiven week for a calendar year.","ref":"Cldr.Calendar.html#c:week/2"},{"type":"function","title":"Cldr.Calendar.week_of_month/1","doc":"Returns the `{month, week_number}`\nfor a `date`.\n\nThe nature of a week depends on the\ncalendar configuration and therefore\nsome results may be surprising.  For example\nthe date of December 31st 2018 is actually\nin month one of the ISO Week calendar of\n2019.","ref":"Cldr.Calendar.html#week_of_month/1"},{"type":"function","title":"Arguments - Cldr.Calendar.week_of_month/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#week_of_month/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.week_of_month/1","doc":"* a tuple of the form `{month, week}` or\n\n* `{:error, :not_defined}` if the calendar\n  does not support the concept of weeks.","ref":"Cldr.Calendar.html#week_of_month/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.week_of_month/1","doc":"iex> Cldr.Calendar.week_of_month(~D[2019-01-01])\n    {1, 1}\n    iex> Cldr.Calendar.week_of_month(~D[2018-12-31])\n    {1, 1}\n    iex> Cldr.Calendar.week_of_month(~D[2019-01-01 Cldr.Calendar.BasicWeek])\n    {1, 1}\n    iex> Cldr.Calendar.week_of_month(~D[2018-12-31 Cldr.Calendar.BasicWeek])\n    {12, 5}\n    iex> Cldr.Calendar.week_of_month(~D[2018-12-31 Cldr.Calendar.Julian])\n    {:error, :not_defined}","ref":"Cldr.Calendar.html#week_of_month/1-examples"},{"type":"callback","title":"Cldr.Calendar.week_of_month/3","doc":"Returns a tuple of `{month, week_in_month}` for a given `year`, `month` or `week`, and `day`\nfor a a calendar.\n\nThe `week_in_month` is calculated based upon the calendar configuration.","ref":"Cldr.Calendar.html#c:week_of_month/3"},{"type":"function","title":"Cldr.Calendar.week_of_year/1","doc":"Returns the `{year, week_number}`\nfor a `date`.","ref":"Cldr.Calendar.html#week_of_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.week_of_year/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#week_of_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.week_of_year/1","doc":"* a the week of the year as an\n  integer or\n\n* `{:error, :not_defined}` if the calendar\n  does not support the concept of weeks.","ref":"Cldr.Calendar.html#week_of_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.week_of_year/1","doc":"iex> Cldr.Calendar.week_of_year ~D[2019-01-01]\n    {2019, 1}\n    iex> Cldr.Calendar.week_of_year ~D[2019-12-01]\n    {2019, 48}\n    iex> Cldr.Calendar.week_of_year ~D[2019-52-01 Cldr.Calendar.NRF]\n    {2019, 52}\n    iex> Cldr.Calendar.week_of_year ~D[2019-26-01 Cldr.Calendar.NRF]\n    {2019, 26}\n    iex> Cldr.Calendar.week_of_year ~D[2019-12-01 Cldr.Calendar.Julian]\n    {:error, :not_defined}","ref":"Cldr.Calendar.html#week_of_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.week_of_year/3","doc":"Returns a tuple of `{year, week_in_year}` for a given `year`, `month` or `week`, and `day`\nfor a a calendar.\n\nThe `week_in_year` is calculated based upon the calendar configuration.","ref":"Cldr.Calendar.html#c:week_of_year/3"},{"type":"function","title":"Cldr.Calendar.weekday?/2","doc":"Returns whether a given date is a weekday.\n\nWeekdays are locale-specific and depend on\nthe policies of a given territory (country).","ref":"Cldr.Calendar.html#weekday?/2"},{"type":"function","title":"Arguments - Cldr.Calendar.weekday?/2","doc":"* `date` is any `t:Date.t/0`.\n\n* `options` is a `t:Keyword.t/0` list of options.","ref":"Cldr.Calendar.html#weekday?/2-arguments"},{"type":"function","title":"Options - Cldr.Calendar.weekday?/2","doc":"* `:locale` is any locale or locale name validated\n  by `Cldr.validate_locale/2`.  The default is\n  `Cldr.get_locale()` which returns the locale\n  set for the current process.\n\n* `:territory` is any valid ISO-3166-2 territory\n  that is validated by `Cldr.validate_territory/1`.\n\n* `:backend` is any `Cldr` backend module. See the\n  [backend configuration](https://hexdocs.pm/ex_cldr/readme.html#configuration)\n  documentation for further information. The default\n  is `Cldr.Calendar.Backend.Default` which configures\n  only the `en` locale.","ref":"Cldr.Calendar.html#weekday?/2-options"},{"type":"function","title":"Notes - Cldr.Calendar.weekday?/2","doc":"When identifying which territory context within which\nto determine whether a given day is a weekday or not\nthe following order applies:\n\n* A territory specified by the `:territory` option.\n\n* The territory defined as part of the `:locale` option.\n\n* The territory defined as part of the current processes\n  default locale.","ref":"Cldr.Calendar.html#weekday?/2-notes"},{"type":"function","title":"Examples - Cldr.Calendar.weekday?/2","doc":"# The default locale for `Cldr` is `en-001` for which\n    # the territory is `001` (the world). The weekdays\n    # for `001` are Monday to Friday\n    iex> Cldr.Calendar.weekday? ~D[2019-03-23], locale: :en\n    false\n\n    iex> Cldr.Calendar.weekday? ~D[2019-03-23], territory: \"IS\"\n    false\n\n    # Saturday is a weekday in India\n    iex> Cldr.Calendar.weekday? ~D[2019-03-23], locale: :\"en-IN\", backend: MyApp.Cldr\n    true\n\n    # Friday is not a weekday in Saudi Arabia\n    iex> Cldr.Calendar.weekday? ~D[2019-03-22], locale: :\"ar-SA\", backend: MyApp.Cldr\n    false\n\n    # Friday is not a weekday in Israel\n    iex> Cldr.Calendar.weekday? ~D[2019-03-22], locale: :he, backend: MyApp.Cldr\n    false","ref":"Cldr.Calendar.html#weekday?/2-examples"},{"type":"function","title":"Cldr.Calendar.weekdays/1","doc":"Returns a list of the days of the week that\nare considered a weekend for a given\nterritory (country).","ref":"Cldr.Calendar.html#weekdays/1"},{"type":"function","title":"Arguments - Cldr.Calendar.weekdays/1","doc":"* `territory` is any valid ISO3166-2 code.","ref":"Cldr.Calendar.html#weekdays/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.weekdays/1","doc":"* A list of integers representing the days of\n  the week that are week days.","ref":"Cldr.Calendar.html#weekdays/1-returns"},{"type":"function","title":"Notes - Cldr.Calendar.weekdays/1","doc":"The list of days may not my monotonic. See\nthe example for Saudi Arabia below.","ref":"Cldr.Calendar.html#weekdays/1-notes"},{"type":"function","title":"Examples - Cldr.Calendar.weekdays/1","doc":"iex> Cldr.Calendar.weekdays(\"US\")\n    [1, 2, 3, 4, 5]\n\n    iex> Cldr.Calendar.weekdays(\"IN\")\n    [1, 2, 3, 4, 5, 6]\n\n    iex> Cldr.Calendar.weekdays(\"SA\")\n    [1, 2, 3, 4, 7]\n\n    iex> Cldr.Calendar.weekdays(\"yy\")\n    {:error, {Cldr.UnknownTerritoryError, \"The territory \\\"yy\\\" is unknown\"}}","ref":"Cldr.Calendar.html#weekdays/1-examples"},{"type":"function","title":"Cldr.Calendar.weekend/1","doc":"Returns a list of the days of the week that\nare considered a weekend for a given\nterritory (country).","ref":"Cldr.Calendar.html#weekend/1"},{"type":"function","title":"Arguments - Cldr.Calendar.weekend/1","doc":"* `territory` is any valid ISO3166-2 code.","ref":"Cldr.Calendar.html#weekend/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.weekend/1","doc":"* A list of integers representing the days of\n  the week that are weekend days.","ref":"Cldr.Calendar.html#weekend/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.weekend/1","doc":"iex> Cldr.Calendar.weekend(\"US\")\n    [6, 7]\n\n    iex> Cldr.Calendar.weekend(\"IN\")\n    [7]\n\n    iex> Cldr.Calendar.weekend(\"SA\")\n    [5, 6]\n\n    iex> Cldr.Calendar.weekend(\"yy\")\n    {:error, {Cldr.UnknownTerritoryError, \"The territory \\\"yy\\\" is unknown\"}}","ref":"Cldr.Calendar.html#weekend/1-examples"},{"type":"function","title":"Cldr.Calendar.weekend?/2","doc":"Returns whether a given date is a weekend day.\n\nWeekend days are locale-specific and depend on\nthe policies of a given territory (country).","ref":"Cldr.Calendar.html#weekend?/2"},{"type":"function","title":"Arguments - Cldr.Calendar.weekend?/2","doc":"* `date` is any `t:Date.t/0`.\n\n* `options` is a `t:Keyword.t/0` list of options.","ref":"Cldr.Calendar.html#weekend?/2-arguments"},{"type":"function","title":"Options - Cldr.Calendar.weekend?/2","doc":"* `:locale` is any locale or locale name validated\n  by `Cldr.validate_locale/2`.  The default is\n  `Cldr.get_locale()` which returns the locale\n  set for the current process.\n\n* `:territory` is any valid ISO-3166-2 territory\n  that is validated by `Cldr.validate_territory/1`.\n\n* `:backend` is any `Cldr` backend module. See the\n  [backend configuration](https://hexdocs.pm/ex_cldr/readme.html#configuration)\n  documentation for further information. The default\n  is `Cldr.Calendar.Backend.Default` which configures\n  only the `en` locale.","ref":"Cldr.Calendar.html#weekend?/2-options"},{"type":"function","title":"Notes - Cldr.Calendar.weekend?/2","doc":"When identifying which territory context within which\nto determine whether a given day is a weekend or not\nthe following order applies:\n\n* A territory specified by the `:territory` option.\n\n* The territory defined as part of the `:locale` option.\n\n* The territory defined as part of the current processes\n  default locale.","ref":"Cldr.Calendar.html#weekend?/2-notes"},{"type":"function","title":"Examples - Cldr.Calendar.weekend?/2","doc":"# The default locale for `Cldr` is `en-001` for which\n    # the territory is `001` (the world). The weekend\n    # for `001` is Saturday and Sunday\n    iex> Cldr.Calendar.weekend? ~D[2019-03-23]\n    true\n\n    iex> Cldr.Calendar.weekend? ~D[2019-03-23], locale: :en\n    true\n\n    iex> Cldr.Calendar.weekend? ~D[2019-03-23], territory: \"IS\"\n    true\n\n    # In India the official weekend is only Sunday\n    iex> Cldr.Calendar.weekend? ~D[2019-03-23], locale: \"en-IN\", backend: MyApp.Cldr\n    false\n\n    # In Israel the weekend starts on Friday\n    iex> Cldr.Calendar.weekend? ~D[2019-03-22], locale: :he, backend: MyApp.Cldr\n    true\n\n    # As it also does in Saudia Arabia\n    iex> Cldr.Calendar.weekend? ~D[2019-03-22], locale: :\"ar-SA\", backend: MyApp.Cldr\n    true\n\n    # Sunday is not a weekend day in Saudi Arabia\n    iex> Cldr.Calendar.weekend? ~D[2019-03-24], locale: :\"ar-SA\", backend: MyApp.Cldr\n    false","ref":"Cldr.Calendar.html#weekend?/2-examples"},{"type":"function","title":"Cldr.Calendar.weeks_in_year/1","doc":"Returns the number of weeks in a year.","ref":"Cldr.Calendar.html#weeks_in_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.weeks_in_year/1","doc":"* `date` is any `t:Date.t/0` or an integer year\n  or a map with one or more of the fields `:year`,\n  `:month`, `:day` and optionally `:calendar`.","ref":"Cldr.Calendar.html#weeks_in_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.weeks_in_year/1","doc":"* `{weeks_in_year, days_in_last_week}`","ref":"Cldr.Calendar.html#weeks_in_year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.weeks_in_year/1","doc":"# For the default Calendar.ISO calendar the number of\n    # weeks in a year is either 52 or 53 with each week\n    # being 7 days. The first week may start in the Gregorian\n    # year prior and end in the following Gregorian year.\n\n    iex> Cldr.Calendar.weeks_in_year ~D[2022-01-01]\n    {52, 7}\n\n    iex> Cldr.Calendar.weeks_in_year ~D[2023-01-01]\n    {53, 7}\n\n    # For week calculations, the Cldr.Calendar.ISO and Cldr.Calendar.ISOWeek\n    # have the same definition.\n\n    iex> Cldr.Calendar.weeks_in_year 2023, Cldr.Calendar.ISO\n    {52, 7}\n\n    iex> Cldr.Calendar.weeks_in_year 2020, Cldr.Calendar.ISOWeek\n    {53, 7}\n\n    iex> Cldr.Calendar.weeks_in_year ~D[2026-W01-1 Cldr.Calendar.ISOWeek]\n    {53, 7}\n\n    # For calendars that are configured to have the first week\n    # start on the first day of the year there will be a final\n    # week 53 with either 1 or 2 days.\n\n    iex> Cldr.Calendar.SequentialWeeks.weeks_in_year 2023\n    {53, 1}\n\n    iex> Cldr.Calendar.SequentialWeeks.weeks_in_year 2020\n    {53, 2}","ref":"Cldr.Calendar.html#weeks_in_year/1-examples"},{"type":"callback","title":"Cldr.Calendar.weeks_in_year/1","doc":"Returns the number of weeks in a year","ref":"Cldr.Calendar.html#c:weeks_in_year/1"},{"type":"function","title":"Cldr.Calendar.weeks_in_year/2","doc":"","ref":"Cldr.Calendar.html#weeks_in_year/2"},{"type":"function","title":"Cldr.Calendar.weeks_to_days/1","doc":"Returns the number of days in `n` weeks","ref":"Cldr.Calendar.html#weeks_to_days/1"},{"type":"function","title":"Example - Cldr.Calendar.weeks_to_days/1","doc":"iex> Cldr.Calendar.weeks_to_days(2)\n    14","ref":"Cldr.Calendar.html#weeks_to_days/1-example"},{"type":"type","title":"Cldr.Calendar.year/0","doc":"Specifies the year of a date as either\na positive integer or nil.","ref":"Cldr.Calendar.html#t:year/0"},{"type":"callback","title":"Cldr.Calendar.year/1","doc":"Returns a date range representing the days in a\ncalendar year.","ref":"Cldr.Calendar.html#c:year/1"},{"type":"function","title":"Cldr.Calendar.year_of_era/1","doc":"Returns the `{year_of_era, era}` for\na `date`.\n\n*This function differs slightly\nfrom `Date.year_of_era/1`. See the notes\nbelow*","ref":"Cldr.Calendar.html#year_of_era/1"},{"type":"function","title":"Arguments - Cldr.Calendar.year_of_era/1","doc":"* `date` is any `t:Date.t/0` or a map with one or\n  more of the fields `:year`, `:month`, `:day` and\n  optionally `:calendar`.","ref":"Cldr.Calendar.html#year_of_era/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.year_of_era/1","doc":"* a the year since the start of the era and\n  the era of the year as a tuple.","ref":"Cldr.Calendar.html#year_of_era/1-returns"},{"type":"function","title":"Notes - Cldr.Calendar.year_of_era/1","doc":"1. Unlike `Date.year_of_era/1`, this function supports\n  eras that change part way through the calendar\n  year. This is common in the Japanese calendar where\n  the eras change when a new emperor is ordained which\n  can happen at any time of year. Therefore this\n  function is consistent with `Date.year_of_era/1` for\n  the Gregorian and related calendars, but returns a\n  different (and more accurate) result for the Japanese\n  calendar.\n\n2. This is also true for fiscal year calendars that\n  start on a day other than January 1st. The year of\n  era will depend on whether the calendar was configured\n  with `year: :beginning`, `year: :ending` or `year: :majority`.","ref":"Cldr.Calendar.html#year_of_era/1-notes"},{"type":"function","title":"Examples - Cldr.Calendar.year_of_era/1","doc":"iex> Cldr.Calendar.year_of_era ~D[2019-01-01]\n    {2019, 1}\n\n    iex> Cldr.Calendar.year_of_era Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.NRF)\n    {2019, 1}\n\n    iex> Cldr.Calendar.year_of_era Cldr.Calendar.last_day_of_year(2019, Cldr.Calendar.NRF)\n    {2019, 1}","ref":"Cldr.Calendar.html#year_of_era/1-examples"},{"type":"module","title":"Cldr.Calendar.Behaviour","doc":"","ref":"Cldr.Calendar.Behaviour.html"},{"type":"module","title":"Cldr.Calendar.Config","doc":"Defines the configuration for a calendar.\n\nSee `Cldr.Calendar.new/3` for usage details.","ref":"Cldr.Calendar.Config.html"},{"type":"function","title":"Cldr.Calendar.Config.first_day_for_locale/2","doc":"","ref":"Cldr.Calendar.Config.html#first_day_for_locale/2"},{"type":"function","title":"Cldr.Calendar.Config.min_days_for_locale/2","doc":"","ref":"Cldr.Calendar.Config.html#min_days_for_locale/2"},{"type":"type","title":"Cldr.Calendar.Config.t/0","doc":"Defines the struct type for a calendar configuration","ref":"Cldr.Calendar.Config.html#t:t/0"},{"type":"module","title":"Cldr.Calendar.Duration","doc":"Functions to create and format a difference between\ntwo dates, times or datetimes.\n\nThe difference between two dates (or times or datetimes) is\nusually defined in terms of days or seconds.\n\nA duration is calculated as the difference in time in calendar\nunits: years, months, days, hours, minutes, seconds and microseconds.\n\nThis is useful to support formatting a string for users in\neasy-to-understand terms. For example `11 months, 3 days and 4 minutes`\nis a lot easier to understand than `28771440` seconds.\n\nThe package [ex_cldr_units](https://hex.pm/packages/ex_cldr_units) can\nbe optionally configured to provide localized formatting of durations.\n\nIf configured, the following providers should be configured in the\nappropriate CLDR backend module. For example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"ja\"],\n    providers: [Cldr.Calendar, Cldr.Number, Cldr.Unit, Cldr.List]\nend\n```","ref":"Cldr.Calendar.Duration.html"},{"type":"type","title":"Cldr.Calendar.Duration.date_or_time_or_datetime/0","doc":"A date, time, naivedatetime or datetime","ref":"Cldr.Calendar.Duration.html#t:date_or_time_or_datetime/0"},{"type":"type","title":"Cldr.Calendar.Duration.interval/0","doc":"A interval as either Date.Range.t() CalendarInterval.t()","ref":"Cldr.Calendar.Duration.html#t:interval/0"},{"type":"function","title":"Cldr.Calendar.Duration.new/1","doc":"Calculates the calendar difference in\na `Date.Range` or `CalendarInterval`\nreturning a `Duration` struct.\n\nThe difference calculated is in terms of years, months,\ndays, hours, minutes, seconds and microseconds.","ref":"Cldr.Calendar.Duration.html#new/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.new/1","doc":"* `interval` is either `t:Date.Range.t/0` or a\n  `CalendarInterval.t()`","ref":"Cldr.Calendar.Duration.html#new/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Duration.new/1","doc":"* A `{:ok, duration}` tuple or a\n\n* `{:error, {exception, reason}}` tuple","ref":"Cldr.Calendar.Duration.html#new/1-returns"},{"type":"function","title":"Notes - Cldr.Calendar.Duration.new/1","doc":"* `CalendarInterval` is defined by the most wonderful\n  [calendar_interval](https://hex.pm/packages/calendar_interval)\n  library.","ref":"Cldr.Calendar.Duration.html#new/1-notes"},{"type":"function","title":"Example - Cldr.Calendar.Duration.new/1","doc":"iex> Cldr.Calendar.Duration.new(Date.range(~D[2019-01-01], ~D[2019-12-31]))\n    {:ok,\n     %Cldr.Calendar.Duration{\n       year: 0,\n       month: 11,\n       day: 30,\n       hour: 0,\n       microsecond: {0, 6},\n       minute: 0,\n       second: 0\n     }}","ref":"Cldr.Calendar.Duration.html#new/1-example"},{"type":"function","title":"Cldr.Calendar.Duration.new/2","doc":"Calculates the calendar difference between two dates\nreturning a `Duration` struct.\n\nThe difference calculated is in terms of years, months,\ndays, hours, minutes, seconds and microseconds.","ref":"Cldr.Calendar.Duration.html#new/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.new/2","doc":"* `from` is a date, time or datetime representing the\n  start of the duration.\n\n* `to` is a date, time or datetime representing the\n  end of the duration","ref":"Cldr.Calendar.Duration.html#new/2-arguments"},{"type":"function","title":"Notes - Cldr.Calendar.Duration.new/2","doc":"* `from` must be before or at the same time\n  as `to`. In addition, both `from` and `to` must\n  be in the same calendar\n\n* If `from` and `to` are `datetime`s then\n  they must both be in the same time zone","ref":"Cldr.Calendar.Duration.html#new/2-notes"},{"type":"function","title":"Returns - Cldr.Calendar.Duration.new/2","doc":"* A `{:ok, duration}` tuple or a\n\n* `{:error, {exception, reason}}` tuple","ref":"Cldr.Calendar.Duration.html#new/2-returns"},{"type":"function","title":"Example - Cldr.Calendar.Duration.new/2","doc":"iex> Cldr.Calendar.Duration.new(~D[2019-01-01], ~D[2019-12-31])\n    {:ok,\n     %Cldr.Calendar.Duration{\n       year: 0,\n       month: 11,\n       day: 30,\n       hour: 0,\n       microsecond: {0, 6},\n       minute: 0,\n       second: 0\n     }}","ref":"Cldr.Calendar.Duration.html#new/2-example"},{"type":"function","title":"Cldr.Calendar.Duration.new!/1","doc":"Calculates the calendar difference in\na `Date.Range` or `CalendarInterval`\nreturning a `Duration` struct.\n\nThe difference calculated is in terms of years, months,\ndays, hours, minutes, seconds and microseconds.","ref":"Cldr.Calendar.Duration.html#new!/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.new!/1","doc":"* `interval` is either ` Date.Range.t()` or a\n  `CalendarInterval.t()`","ref":"Cldr.Calendar.Duration.html#new!/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Duration.new!/1","doc":"* A `t:Cldr.Calendar.Duration.t/0` struct or\n\n* raises an exception","ref":"Cldr.Calendar.Duration.html#new!/1-returns"},{"type":"function","title":"Notes - Cldr.Calendar.Duration.new!/1","doc":"* `CalendarInterval` is defined by the most wonderful\n  [calendar_interval](https://hex.pm/packages/calendar_interval)\n  library.","ref":"Cldr.Calendar.Duration.html#new!/1-notes"},{"type":"function","title":"Example - Cldr.Calendar.Duration.new!/1","doc":"iex> Cldr.Calendar.Duration.new!(Date.range(~D[2019-01-01], ~D[2019-12-31]))\n    %Cldr.Calendar.Duration{\n      year: 0,\n      month: 11,\n      day: 30,\n      hour: 0,\n      microsecond: {0, 6},\n      minute: 0,\n      second: 0\n    }","ref":"Cldr.Calendar.Duration.html#new!/1-example"},{"type":"function","title":"Cldr.Calendar.Duration.new!/2","doc":"Calculates the calendar difference between two dates\nreturning a `Duration` struct.\n\nThe difference calculated is in terms of years, months,\ndays, hours, minutes, seconds and microseconds.","ref":"Cldr.Calendar.Duration.html#new!/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.new!/2","doc":"* `from` is a date, time or datetime representing the\n  start of the duration\n\n* `to` is a date, time or datetime representing the\n  end of the duration\n\nNote that `from` must be before or at the same time\nas `to`. In addition, both `from` and `to` must\nbe in the same calendar.","ref":"Cldr.Calendar.Duration.html#new!/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Duration.new!/2","doc":"* A `t:Cldr.Calendar.Duration.t/0` struct or\n\n* raises an exception","ref":"Cldr.Calendar.Duration.html#new!/2-returns"},{"type":"function","title":"Example - Cldr.Calendar.Duration.new!/2","doc":"iex> Cldr.Calendar.Duration.new!(~D[2019-01-01], ~D[2019-12-31])\n    %Cldr.Calendar.Duration{\n      year: 0,\n      month: 11,\n      day: 30,\n      hour: 0,\n      microsecond: {0, 6},\n      minute: 0,\n      second: 0\n    }","ref":"Cldr.Calendar.Duration.html#new!/2-example"},{"type":"function","title":"Cldr.Calendar.Duration.new_from_seconds/1","doc":"Returns a duration calculated from a number of seconds.\n\nThe duration will be calculated in hours, minutes,\nseconds and microseconds only.","ref":"Cldr.Calendar.Duration.html#new_from_seconds/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.new_from_seconds/1","doc":"* `seconds` is a number of seconds as a float or\n  integer.","ref":"Cldr.Calendar.Duration.html#new_from_seconds/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Duration.new_from_seconds/1","doc":"* a `t:Cldr.Calendar.Duration.t/0`","ref":"Cldr.Calendar.Duration.html#new_from_seconds/1-returns"},{"type":"function","title":"Example - Cldr.Calendar.Duration.new_from_seconds/1","doc":"iex> Cldr.Calendar.Duration.new_from_seconds(36092.1)\n    %Cldr.Calendar.Duration{\n      year: 0,\n      month: 0,\n      day: 0,\n      hour: 10,\n      minute: 1,\n      second: 32,\n      microsecond: {100000, 1}\n    }","ref":"Cldr.Calendar.Duration.html#new_from_seconds/1-example"},{"type":"type","title":"Cldr.Calendar.Duration.t/0","doc":"Duration in calendar units","ref":"Cldr.Calendar.Duration.html#t:t/0"},{"type":"function","title":"Cldr.Calendar.Duration.to_string/2","doc":"Returns a string formatted representation of\na duration.\n\nNote that time units that are zero are omitted\nfrom the output.\n\nFormatting is","ref":"Cldr.Calendar.Duration.html#to_string/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.to_string/2","doc":"* `duration` is a duration of type `t:Cldr.Calendar.Duration.t/0` returned\n  by `Cldr.Calendar.Duration.new/2`\n\n* `options` is a Keyword list of options","ref":"Cldr.Calendar.Duration.html#to_string/2-arguments"},{"type":"function","title":"Options - Cldr.Calendar.Duration.to_string/2","doc":"* `:except` is a list of time units to be omitted from\n  the formatted output. It may be useful to use\n  `except: [:microsecond]` for example. The default is\n  `[]`.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  The default is `Cldr.get_locale/0`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`\n\n* `:list_options` is a list of options passed to `Cldr.List.to_string/3` to\n  control the final list output.\n\nAny other options are passed to `Cldr.Number.to_string/3` and\n`Cldr.Unit.to_string/3` during the formatting process.","ref":"Cldr.Calendar.Duration.html#to_string/2-options"},{"type":"function","title":"Note - Cldr.Calendar.Duration.to_string/2","doc":"* Any duration parts that are `0` are not output.","ref":"Cldr.Calendar.Duration.html#to_string/2-note"},{"type":"function","title":"Example - Cldr.Calendar.Duration.to_string/2","doc":"iex> {:ok, duration} = Cldr.Calendar.Duration.new(~D[2019-01-01], ~D[2019-12-31])\n    iex> Cldr.Calendar.Duration.to_string(duration)\n    {:ok, \"11 months and 30 days\"}","ref":"Cldr.Calendar.Duration.html#to_string/2-example"},{"type":"function","title":"Cldr.Calendar.Duration.to_string!/2","doc":"Formats a duration as a string or raises\nan exception on error.","ref":"Cldr.Calendar.Duration.html#to_string!/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Duration.to_string!/2","doc":"* `duration` is a duration of type `t:Cldr.Calendar.Duration.t/0` returned\n  by `Cldr.Calendar.Duration.new/2`.\n\n* `options` is a Keyword list of options.","ref":"Cldr.Calendar.Duration.html#to_string!/2-arguments"},{"type":"function","title":"Options - Cldr.Calendar.Duration.to_string!/2","doc":"See `Cldr.Calendar.Duration.to_string/2`.","ref":"Cldr.Calendar.Duration.html#to_string!/2-options"},{"type":"function","title":"Returns - Cldr.Calendar.Duration.to_string!/2","doc":"* A formatted string or\n\n* raises an exception.","ref":"Cldr.Calendar.Duration.html#to_string!/2-returns"},{"type":"module","title":"Cldr.Calendar.Era","doc":"Encapsulates the era information for\nknown CLDR calendars.\n\nThe [era data in CLDR](https://github.com/unicode-org/cldr/blob/master/common/supplemental/supplementalData.xml)\nis presented in different calendars at different times. The current\nbest understanding is:","ref":"Cldr.Calendar.Era.html"},{"type":"module","title":"Japanese Calendar - Cldr.Calendar.Era","doc":"* From Taisho (1912), the date is Gregorian year,\n  month and day.\n\n* For Tenshō (Momoyama period) to Meji era (1868)\n  inclusive its Gregorian year but lunar month and day.\n\n* For earlier eras it is Julian year with lunar month and\n  day (but the Julian and Gregorian years coincide; there are\n  no era dates where the Gregorian year would be different\n  to the Julian year).","ref":"Cldr.Calendar.Era.html#module-japanese-calendar"},{"type":"module","title":"Other Calendars - Cldr.Calendar.Era","doc":"* For Chinese and Korean (dangi) the era dates are\n  Gregorian year with lunar month and lunar day\n\n* For Coptic, Ethiopic and Islamic calendars the eras are\n  Julian dates (Julian day, month and year).\n\n* Persian era is Julian year with persian month and day.\n\n* Gregorian is, well, Gregorian date.","ref":"Cldr.Calendar.Era.html#module-other-calendars"},{"type":"function","title":"Cldr.Calendar.Era.era_module/1","doc":"Return the era module for a given\ncldr calendar type.","ref":"Cldr.Calendar.Era.html#era_module/1"},{"type":"module","title":"Cldr.Calendar.FiscalYear","doc":"","ref":"Cldr.Calendar.FiscalYear.html"},{"type":"function","title":"Cldr.Calendar.FiscalYear.calendar_for/1","doc":"","ref":"Cldr.Calendar.FiscalYear.html#calendar_for/1"},{"type":"function","title":"Cldr.Calendar.FiscalYear.known_fiscal_calendars/0","doc":"","ref":"Cldr.Calendar.FiscalYear.html#known_fiscal_calendars/0"},{"type":"function","title":"Cldr.Calendar.FiscalYear.known_fiscal_years/0","doc":"","ref":"Cldr.Calendar.FiscalYear.html#known_fiscal_years/0"},{"type":"module","title":"Cldr.Calendar.Gregorian","doc":"Implements the proleptic Gregorian calendar.\n\nIntended to be plug-compatible with `Calendar.ISO`\nwith additional functions to support localisation,\ndate ranges for `year`, `quarter`, `month` and `week`.\n\nWhen calling `Cldr.Calendar.localize/3` on a\n`Calendar.ISO`-based date, those dates are first\nmoved to this calendar acting as a localisation\nproxy.","ref":"Cldr.Calendar.Gregorian.html"},{"type":"function","title":"Cldr.Calendar.Gregorian.add/9","doc":"Adds `:year`, `:quarter`, `:month`, `:week` increments\n\nThese functions support `CalendarInterval`","ref":"Cldr.Calendar.Gregorian.html#add/9"},{"type":"function","title":"Cldr.Calendar.Gregorian.calendar_base/0","doc":"Identifies that the calendar is month based.","ref":"Cldr.Calendar.Gregorian.html#calendar_base/0"},{"type":"function","title":"Cldr.Calendar.Gregorian.calendar_year/3","doc":"Returns the calendar year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#calendar_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.cldr_calendar_type/0","doc":"Defines the CLDR calendar type for this calendar.\n\nThis type is used in support of `Cldr.Calendar.localize/3`.\nCurrently only `:gregorian` or `:japanese` are supported.","ref":"Cldr.Calendar.Gregorian.html#cldr_calendar_type/0"},{"type":"function","title":"Cldr.Calendar.Gregorian.cyclic_year/3","doc":"Returns the cyclic year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#cyclic_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.date_from_iso_days/1","doc":"Returns `{year, month, day}` calculated from\nthe number of `iso_days`.","ref":"Cldr.Calendar.Gregorian.html#date_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.date_to_iso_days/3","doc":"Returns the number of days since the calendar\nepoch for a given `year-month-day`","ref":"Cldr.Calendar.Gregorian.html#date_to_iso_days/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.day_of_era/3","doc":"Calculates the day and era from the given `year`, `month`, and `day`.","ref":"Cldr.Calendar.Gregorian.html#day_of_era/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.day_of_week/4","doc":"Calculates the day of the week from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.Gregorian.html#day_of_week/4"},{"type":"function","title":"Cldr.Calendar.Gregorian.day_of_year/3","doc":"Calculates the day of the year from the given `year`, `month`, and `day`.","ref":"Cldr.Calendar.Gregorian.html#day_of_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.days_in_month/1","doc":"Returns how many days there are in the given month.\n\nIf the days in month cannot be determined without\nknowning the year and error tuple is returned.","ref":"Cldr.Calendar.Gregorian.html#days_in_month/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.days_in_month/2","doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.Gregorian.html#days_in_month/2"},{"type":"function","title":"Cldr.Calendar.Gregorian.days_in_week/0","doc":"Returns the number days in a week.","ref":"Cldr.Calendar.Gregorian.html#days_in_week/0"},{"type":"function","title":"Cldr.Calendar.Gregorian.days_in_year/1","doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.Gregorian.html#days_in_year/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.extended_year/3","doc":"Returns the extended year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#extended_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.first_gregorian_day_of_year/1","doc":"Returns the number of `iso_days` that is\nthe first day of the given\nyear for this calendar.","ref":"Cldr.Calendar.Gregorian.html#first_gregorian_day_of_year/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.iso_week_of_year/3","doc":"Calculates the ISO week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.Gregorian.html#iso_week_of_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.last_gregorian_day_of_year/1","doc":"Returns the number of `iso_days` that is\nthe last day of the given\nyear for this calendar.","ref":"Cldr.Calendar.Gregorian.html#last_gregorian_day_of_year/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.leap_year?/1","doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.Gregorian.html#leap_year?/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.month/2","doc":"Returns a `t:Date.Range` representing\na given month of a year.","ref":"Cldr.Calendar.Gregorian.html#month/2"},{"type":"function","title":"Cldr.Calendar.Gregorian.month_of_year/3","doc":"Calculates the month of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 12.","ref":"Cldr.Calendar.Gregorian.html#month_of_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.naive_datetime_from_iso_days/1","doc":"Converts the `t:Calendar.iso_days` format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.Gregorian.html#naive_datetime_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.naive_datetime_to_iso_days/7","doc":"Returns the `t:Calendar.iso_days` format of the specified date.","ref":"Cldr.Calendar.Gregorian.html#naive_datetime_to_iso_days/7"},{"type":"function","title":"Cldr.Calendar.Gregorian.periods_in_year/1","doc":"Calculates the number of period in a given `year`. A period\ncorresponds to a month in month-based calendars and\na week in week-based calendars.","ref":"Cldr.Calendar.Gregorian.html#periods_in_year/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.plus/6","doc":"Adds an `increment` number of `date_part`s\nto a `year-month-day`.\n\n`date_part` can be `:years`, `:quarters`\n`:months` or `:days`.","ref":"Cldr.Calendar.Gregorian.html#plus/6"},{"type":"function","title":"Cldr.Calendar.Gregorian.quarter/2","doc":"Returns a `t:Date.Range` representing\na given quarter of a year.","ref":"Cldr.Calendar.Gregorian.html#quarter/2"},{"type":"function","title":"Cldr.Calendar.Gregorian.quarter_of_year/3","doc":"Calculates the quarter of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 4.","ref":"Cldr.Calendar.Gregorian.html#quarter_of_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.related_gregorian_year/3","doc":"Returns the related gregorain year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Gregorian.html#related_gregorian_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.shift_date/4","doc":"Shifts a date by given duration.","ref":"Cldr.Calendar.Gregorian.html#shift_date/4"},{"type":"function","title":"Cldr.Calendar.Gregorian.shift_naive_datetime/8","doc":"Shifts a naive date time by given duration.","ref":"Cldr.Calendar.Gregorian.html#shift_naive_datetime/8"},{"type":"function","title":"Cldr.Calendar.Gregorian.shift_time/5","doc":"Shifts a time by given duration.","ref":"Cldr.Calendar.Gregorian.html#shift_time/5"},{"type":"function","title":"Cldr.Calendar.Gregorian.valid_date?/3","doc":"Determines if the date given is valid according to this calendar.","ref":"Cldr.Calendar.Gregorian.html#valid_date?/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.week/2","doc":"Returns a `t:Date.Range` representing\na given week of a year.","ref":"Cldr.Calendar.Gregorian.html#week/2"},{"type":"function","title":"Cldr.Calendar.Gregorian.week_of_month/3","doc":"Calculates the week of the month from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 5.","ref":"Cldr.Calendar.Gregorian.html#week_of_month/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.week_of_year/3","doc":"Calculates the week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.Gregorian.html#week_of_year/3"},{"type":"function","title":"Cldr.Calendar.Gregorian.weeks_in_year/1","doc":"Returns the number weeks in a given year.\n\nNote that for Gregorian month-based calendars the\nnumber of weeks returned will be 53 (not the sometimes\nexpected 52) since there is always a week 53 with\n1 or 2 (in a leap year) additional days in the\nlast week.","ref":"Cldr.Calendar.Gregorian.html#weeks_in_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Gregorian.weeks_in_year/1","doc":"* `year` is any `t:Calendar.year/0`","ref":"Cldr.Calendar.Gregorian.html#weeks_in_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Gregorian.weeks_in_year/1","doc":"* `{weeks_in_year, days_in_last_week}`","ref":"Cldr.Calendar.Gregorian.html#weeks_in_year/1-returns"},{"type":"function","title":"Example - Cldr.Calendar.Gregorian.weeks_in_year/1","doc":"iex> Cldr.Calendar.Gregorian.weeks_in_year(2019)\n    {53, 1}\n\n    iex> Cldr.Calendar.Gregorian.weeks_in_year(2020)\n    {53, 2}","ref":"Cldr.Calendar.Gregorian.html#weeks_in_year/1-example"},{"type":"function","title":"Cldr.Calendar.Gregorian.year/1","doc":"Returns a `t:Date.Range` representing\na given year.","ref":"Cldr.Calendar.Gregorian.html#year/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.year_of_era/1","doc":"Calculates the year and era from the given `year`.\n\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.Gregorian.html#year_of_era/1"},{"type":"function","title":"Cldr.Calendar.Gregorian.year_of_era/3","doc":"Calculates the year and era from the given `year`,\n`month` and `day`.\n\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.Gregorian.html#year_of_era/3"},{"type":"module","title":"Cldr.Calendar.ISOWeek","doc":"Implements the ISO Week calendar.\n\nThe ISO Week calendar manages dates\nin a `yyyy-ww-dd` format with each year\nhaving either 52 or 53 weeks.","ref":"Cldr.Calendar.ISOWeek.html"},{"type":"function","title":"Cldr.Calendar.ISOWeek.add/9","doc":"Adds a :year, :month, :day or time increments\n\nThese functions support CalendarInterval","ref":"Cldr.Calendar.ISOWeek.html#add/9"},{"type":"function","title":"Cldr.Calendar.ISOWeek.calendar_base/0","doc":"Identifies that the calendar is week based.","ref":"Cldr.Calendar.ISOWeek.html#calendar_base/0"},{"type":"function","title":"Cldr.Calendar.ISOWeek.calendar_year/3","doc":"Returns the calendar year as displayed\non rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#calendar_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.cldr_calendar_type/0","doc":"Defines the CLDR calendar type for this calendar.\n\nThis type is used in support of `Cldr.Calendar.localize/3`.\nCurrently only `:gregorian` is supported.","ref":"Cldr.Calendar.ISOWeek.html#cldr_calendar_type/0"},{"type":"function","title":"Cldr.Calendar.ISOWeek.cyclic_year/3","doc":"Returns the cyclic year as displayed\non rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#cyclic_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.date_from_iso_days/1","doc":"Returns `{year, month, day}` calculated from\nthe number of `iso_days`.","ref":"Cldr.Calendar.ISOWeek.html#date_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.date_to_iso_days/3","doc":"Returns the number of days since the calendar\nepoch for a given `year-month-day`","ref":"Cldr.Calendar.ISOWeek.html#date_to_iso_days/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.day_of_era/3","doc":"Calculates the day and era from the given `year`, `month`, and `day`.","ref":"Cldr.Calendar.ISOWeek.html#day_of_era/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.day_of_week/4","doc":"Calculates the day of the week from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.ISOWeek.html#day_of_week/4"},{"type":"function","title":"Cldr.Calendar.ISOWeek.day_of_year/3","doc":"Calculates the day of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 366.","ref":"Cldr.Calendar.ISOWeek.html#day_of_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.days_in_month/1","doc":"Returns how many days there are in the given month.\n\nIf the days in month cannot be determined without\nknowning the year and error tuple is returned.","ref":"Cldr.Calendar.ISOWeek.html#days_in_month/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.days_in_month/2","doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.ISOWeek.html#days_in_month/2"},{"type":"function","title":"Cldr.Calendar.ISOWeek.days_in_week/0","doc":"Returns the number days in a a week.","ref":"Cldr.Calendar.ISOWeek.html#days_in_week/0"},{"type":"function","title":"Cldr.Calendar.ISOWeek.days_in_year/1","doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.ISOWeek.html#days_in_year/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.extended_year/3","doc":"Returns the extended year as displayed\non rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#extended_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.first_gregorian_day_of_year/1","doc":"Returns the number of `iso_days` that is\nthe first day of the given\nyear for this calendar.","ref":"Cldr.Calendar.ISOWeek.html#first_gregorian_day_of_year/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.iso_week_of_year/3","doc":"Calculates the ISO week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.ISOWeek.html#iso_week_of_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.last_gregorian_day_of_year/1","doc":"Returns the number of `iso_days` that is\nthe last day of the given\nyear for this calendar.","ref":"Cldr.Calendar.ISOWeek.html#last_gregorian_day_of_year/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.leap_year?/1","doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.ISOWeek.html#leap_year?/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.month/2","doc":"Returns a `Date.Range.t` representing\na given month of a year.","ref":"Cldr.Calendar.ISOWeek.html#month/2"},{"type":"function","title":"Cldr.Calendar.ISOWeek.month_of_year/3","doc":"Calculates the month of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 12.","ref":"Cldr.Calendar.ISOWeek.html#month_of_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.naive_datetime_from_iso_days/1","doc":"Converts the `t:Calendar.iso_days/0` format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.ISOWeek.html#naive_datetime_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.naive_datetime_to_iso_days/7","doc":"Returns the `t:Calendar.iso_days/0` format of the specified date.","ref":"Cldr.Calendar.ISOWeek.html#naive_datetime_to_iso_days/7"},{"type":"function","title":"Cldr.Calendar.ISOWeek.periods_in_year/1","doc":"Calculates the number of period in a given `year`. A period\ncorresponds to a month in month-based calendars and\na week in week-based calendars..","ref":"Cldr.Calendar.ISOWeek.html#periods_in_year/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.plus/6","doc":"Adds an `increment` number of `date_part`s\nto a `year-month-day`.\n\n`date_part` can be `:years`, `:quarters`,\n`:months` or `days`.","ref":"Cldr.Calendar.ISOWeek.html#plus/6"},{"type":"function","title":"Cldr.Calendar.ISOWeek.quarter/2","doc":"Returns a `Date.Range.t` representing\na given quarter of a year.","ref":"Cldr.Calendar.ISOWeek.html#quarter/2"},{"type":"function","title":"Cldr.Calendar.ISOWeek.quarter_of_year/3","doc":"Calculates the quarter of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 4.","ref":"Cldr.Calendar.ISOWeek.html#quarter_of_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.related_gregorian_year/3","doc":"Returns the related gregorian year as displayed\non rendered calendars.","ref":"Cldr.Calendar.ISOWeek.html#related_gregorian_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.shift_date/4","doc":"Shifts a date by given duration.","ref":"Cldr.Calendar.ISOWeek.html#shift_date/4"},{"type":"function","title":"Cldr.Calendar.ISOWeek.shift_naive_datetime/8","doc":"Shifts a naive date time by given duration.","ref":"Cldr.Calendar.ISOWeek.html#shift_naive_datetime/8"},{"type":"function","title":"Cldr.Calendar.ISOWeek.shift_time/5","doc":"Shifts a time by given duration.","ref":"Cldr.Calendar.ISOWeek.html#shift_time/5"},{"type":"function","title":"Cldr.Calendar.ISOWeek.valid_date?/3","doc":"Determines if the date given is valid according to the this calendar.","ref":"Cldr.Calendar.ISOWeek.html#valid_date?/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.week/2","doc":"Returns a `Date.Range.t` representing\na given week of a year.","ref":"Cldr.Calendar.ISOWeek.html#week/2"},{"type":"function","title":"Cldr.Calendar.ISOWeek.week_of_month/3","doc":"Calculates the week of the month from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 5.","ref":"Cldr.Calendar.ISOWeek.html#week_of_month/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.week_of_year/3","doc":"Calculates the week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.ISOWeek.html#week_of_year/3"},{"type":"function","title":"Cldr.Calendar.ISOWeek.weeks_in_year/1","doc":"Returns the number weeks in a given year.","ref":"Cldr.Calendar.ISOWeek.html#weeks_in_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.ISOWeek.weeks_in_year/1","doc":"* `year` is any `t:Calendar.year/0`","ref":"Cldr.Calendar.ISOWeek.html#weeks_in_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.ISOWeek.weeks_in_year/1","doc":"* `{weeks_in_year, days_in_last_week}`","ref":"Cldr.Calendar.ISOWeek.html#weeks_in_year/1-returns"},{"type":"function","title":"Example - Cldr.Calendar.ISOWeek.weeks_in_year/1","doc":"iex> Cldr.Calendar.ISOWeek.weeks_in_year 2020\n    {53, 7}\n\n    iex> Cldr.Calendar.ISOWeek.weeks_in_year 2021\n    {52, 7","ref":"Cldr.Calendar.ISOWeek.html#weeks_in_year/1-example"},{"type":"function","title":"Cldr.Calendar.ISOWeek.year/1","doc":"Returns a `Date.Range.t` representing\na given year.","ref":"Cldr.Calendar.ISOWeek.html#year/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.year_of_era/1","doc":"Calculates the year and era from the given `year`.\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.ISOWeek.html#year_of_era/1"},{"type":"function","title":"Cldr.Calendar.ISOWeek.year_of_era/3","doc":"Calculates the year and era from the given `year`,\n`month` and `day`.\n\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.ISOWeek.html#year_of_era/3"},{"type":"module","title":"Cldr.Calendar.Interval","doc":"Implements functions to return intervals and compare\ndate intervals.\n\nIn particular it provides functions which return an\ninterval (as a `Date.Range.t`) for years, quarters,\nmonths, weeks and days.\n\nIn general, the intervals created with the packaage\n[calendar_interval](https://hex.pm/packages/calendar_interval)\nare to be preferred since they can used over different\ntime precisions whereas the functions in this module are\nall intervals of a day. In order to be used with `ex_cldr_calendars`,\nversion \"~> 0.2\" of [calendar_interval](https://hex.pm/packages/calendar_interval)\nis required.\n\nNote however that as of release `0.2`, [calendar_interval](https://hex.pm/packages/calendar_interval) does\nnot support intervals of `quarters` or `weeks`.","ref":"Cldr.Calendar.Interval.html"},{"type":"function","title":"Cldr.Calendar.Interval.compare/2","doc":"Compare two date ranges.\n\nUses [Allen's Interval Algebra](https://en.wikipedia.org/wiki/Allen%27s_interval_algebra)\nto return one of 13 different relationships:\n\nRelation\t     | Converse\n----------     | --------------\n:precedes\t     | :preceded_by\n:meets         | :met_by\n:overlaps      | :overlapped_by\n:finished_by   | :finishes\n:contains      | :during\n:starts        | :started_by\n:equals        | :equals","ref":"Cldr.Calendar.Interval.html#compare/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Interval.compare/2","doc":"* `range_1` is a `Date.Range.t`\n\n* `range_2` is a `Date.Range.t`","ref":"Cldr.Calendar.Interval.html#compare/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Interval.compare/2","doc":"An atom representing the relationship between the two ranges.","ref":"Cldr.Calendar.Interval.html#compare/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Interval.compare/2","doc":"iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]),\n    ...> Cldr.Calendar.Interval.day(~D[2019-01-02])\n    :meets\n\n    iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]),\n    ...> Cldr.Calendar.Interval.day(~D[2019-01-03])\n    :precedes\n\n    iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-03]),\n    ...> Cldr.Calendar.Interval.day(~D[2019-01-01])\n    :preceded_by\n\n    iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]),\n    ...> Cldr.Calendar.Interval.day(~D[2019-01-01])\n    :met_by\n\n    iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]),\n    ...> Cldr.Calendar.Interval.day(~D[2019-01-02])\n    :equals","ref":"Cldr.Calendar.Interval.html#compare/2-examples"},{"type":"function","title":"Cldr.Calendar.Interval.day/1","doc":"Returns a `Date.Range.t` that represents\nthe `day`.\n\nThe range is enumerable.","ref":"Cldr.Calendar.Interval.html#day/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Interval.day/1","doc":"* `year` is any `year` for `calendar`\n\n* `day` is any `day` in the `year`\n  for `calendar`\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.Interval.html#day/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Interval.day/1","doc":"* A `Date.Range.t()` representing the\n  the enumerable days in the `week`","ref":"Cldr.Calendar.Interval.html#day/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Interval.day/1","doc":"iex> Cldr.Calendar.Interval.day 2019, 52, Cldr.Calendar.Fiscal.US\n    Date.range(~D[2019-02-21 Cldr.Calendar.Fiscal.US], ~D[2019-02-21 Cldr.Calendar.Fiscal.US])\n\n    iex> Cldr.Calendar.Interval.day 2019, 92, Cldr.Calendar.NRF\n    Date.range(~D[2019-W14-1 Cldr.Calendar.NRF], ~D[2019-W14-1 Cldr.Calendar.NRF])\n\n    iex> Cldr.Calendar.Interval.day 2019, 8, Cldr.Calendar.ISOWeek\n    Date.range(~D[2019-W02-1 Cldr.Calendar.ISOWeek], ~D[2019-W02-1 Cldr.Calendar.ISOWeek])","ref":"Cldr.Calendar.Interval.html#day/1-examples"},{"type":"function","title":"Cldr.Calendar.Interval.day/3","doc":"","ref":"Cldr.Calendar.Interval.html#day/3"},{"type":"function","title":"Cldr.Calendar.Interval.month/1","doc":"Returns a `Date.Range.t` that represents\nthe `year`.\n\nThe range is enumerable.","ref":"Cldr.Calendar.Interval.html#month/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Interval.month/1","doc":"* `year` is any `year` for `calendar`\n\n* `month` is any `month` in the `year`\n  for `calendar`\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.Interval.html#month/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Interval.month/1","doc":"* A `Date.Range.t()` representing the\n  the enumerable days in the `month`","ref":"Cldr.Calendar.Interval.html#month/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Interval.month/1","doc":"iex> Cldr.Calendar.Interval.month 2019, 3, Cldr.Calendar.Fiscal.UK\n    Date.range(~D[2019-03-01 Cldr.Calendar.Fiscal.UK], ~D[2019-03-30 Cldr.Calendar.Fiscal.UK])\n\n    iex> Cldr.Calendar.Interval.month 2019, 3, Cldr.Calendar.Fiscal.US\n    Date.range(~D[2019-03-01 Cldr.Calendar.Fiscal.US], ~D[2019-03-31 Cldr.Calendar.Fiscal.US])","ref":"Cldr.Calendar.Interval.html#month/1-examples"},{"type":"function","title":"Cldr.Calendar.Interval.month/3","doc":"","ref":"Cldr.Calendar.Interval.html#month/3"},{"type":"function","title":"Cldr.Calendar.Interval.quarter/1","doc":"Returns a `Date.Range.t` that represents\nthe `quarter`.\n\nThe range is enumerable.","ref":"Cldr.Calendar.Interval.html#quarter/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Interval.quarter/1","doc":"* `year` is any `year` for `calendar`\n\n* `quarter` is any `quarter` in the\n`  year` for `calendar`\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.Interval.html#quarter/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Interval.quarter/1","doc":"* A `Date.Range.t()` representing the\n  the enumerable days in the `quarter`","ref":"Cldr.Calendar.Interval.html#quarter/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Interval.quarter/1","doc":"iex> Cldr.Calendar.Interval.quarter 2019, 2, Cldr.Calendar.Fiscal.UK\n    Date.range(~D[2019-04-01 Cldr.Calendar.Fiscal.UK], ~D[2019-06-30 Cldr.Calendar.Fiscal.UK])\n\n    iex> Cldr.Calendar.Interval.quarter 2019, 2, Cldr.Calendar.ISOWeek\n    Date.range(~D[2019-W14-1 Cldr.Calendar.ISOWeek], ~D[2019-W26-7 Cldr.Calendar.ISOWeek])","ref":"Cldr.Calendar.Interval.html#quarter/1-examples"},{"type":"function","title":"Cldr.Calendar.Interval.quarter/3","doc":"","ref":"Cldr.Calendar.Interval.html#quarter/3"},{"type":"function","title":"Cldr.Calendar.Interval.week/1","doc":"Returns a `Date.Range.t` that represents\nthe `year`.\n\nThe range is enumerable.","ref":"Cldr.Calendar.Interval.html#week/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Interval.week/1","doc":"* `year` is any `year` for `calendar`\n\n* `week` is any `week` in the `year`\n  for `calendar`\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.Interval.html#week/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Interval.week/1","doc":"* A `Date.Range.t()` representing the\n  the enumerable days in the `week` or\n\n* `{:error, :not_defined}` if the calendar\n  does not support the concept of weeks","ref":"Cldr.Calendar.Interval.html#week/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Interval.week/1","doc":"iex> Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.Fiscal.US\n    Date.range(~D[2019-12-22 Cldr.Calendar.Fiscal.US], ~D[2019-12-28 Cldr.Calendar.Fiscal.US])\n\n    iex> Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.NRF\n    Date.range(~D[2019-W52-1 Cldr.Calendar.NRF], ~D[2019-W52-7 Cldr.Calendar.NRF])\n\n    iex> Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.ISOWeek\n    Date.range(~D[2019-W52-1 Cldr.Calendar.ISOWeek], ~D[2019-W52-7 Cldr.Calendar.ISOWeek])\n\n    iex> Cldr.Calendar.Interval.week 2019, 52, Cldr.Calendar.Julian\n    {:error, :not_defined}","ref":"Cldr.Calendar.Interval.html#week/1-examples"},{"type":"function","title":"Cldr.Calendar.Interval.week/3","doc":"","ref":"Cldr.Calendar.Interval.html#week/3"},{"type":"function","title":"Cldr.Calendar.Interval.year/1","doc":"Returns a `Date.Range.t` that represents\nthe `year`.\n\nThe range is enumerable.","ref":"Cldr.Calendar.Interval.html#year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Interval.year/1","doc":"* `year` is any `year` for `calendar`\n\n* `calendar` is any module that implements\n  the `Calendar` and `Cldr.Calendar`\n  behaviours. The default is `Cldr.Calendar.Gregorian`.","ref":"Cldr.Calendar.Interval.html#year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Interval.year/1","doc":"* A `Date.Range.t()` representing the\n  the enumerable days in the `year`","ref":"Cldr.Calendar.Interval.html#year/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Interval.year/1","doc":"iex> Cldr.Calendar.Interval.year 2019, Cldr.Calendar.Fiscal.UK\n    Date.range(~D[2019-01-01 Cldr.Calendar.Fiscal.UK], ~D[2019-12-31 Cldr.Calendar.Fiscal.UK])\n\n    iex> Cldr.Calendar.Interval.year 2019, Cldr.Calendar.NRF\n    Date.range(~D[2019-W01-1 Cldr.Calendar.NRF], ~D[2019-W52-7 Cldr.Calendar.NRF])","ref":"Cldr.Calendar.Interval.html#year/1-examples"},{"type":"function","title":"Cldr.Calendar.Interval.year/2","doc":"","ref":"Cldr.Calendar.Interval.html#year/2"},{"type":"module","title":"Cldr.Calendar.Julian","doc":"","ref":"Cldr.Calendar.Julian.html"},{"type":"function","title":"Cldr.Calendar.Julian.calendar_base/0","doc":"Identifies that this calendar is month based.","ref":"Cldr.Calendar.Julian.html#calendar_base/0"},{"type":"function","title":"Cldr.Calendar.Julian.calendar_year/3","doc":"Returns the calendar year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Julian.html#calendar_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.cldr_calendar_type/0","doc":"Defines the CLDR calendar type for this calendar.\n\nThis type is used in support of `Cldr.Calendar.localize/3`.\nCurrently only `:gregorian` is supported.","ref":"Cldr.Calendar.Julian.html#cldr_calendar_type/0"},{"type":"function","title":"Cldr.Calendar.Julian.cyclic_year/3","doc":"Returns the cyclic year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Julian.html#cyclic_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.date_from_iso_days/1","doc":"Returns a `{year, month, day}` calculated from\nthe number of `iso_days`.","ref":"Cldr.Calendar.Julian.html#date_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.Julian.date_to_iso_days/3","doc":"Returns the number of days since the calendar\nepoch for a given `year-month-day`","ref":"Cldr.Calendar.Julian.html#date_to_iso_days/3"},{"type":"type","title":"Cldr.Calendar.Julian.day/0","doc":"","ref":"Cldr.Calendar.Julian.html#t:day/0"},{"type":"function","title":"Cldr.Calendar.Julian.day_of_era/3","doc":"Calculates the day and era from the given `year`, `month`, and `day`.","ref":"Cldr.Calendar.Julian.html#day_of_era/3"},{"type":"function","title":"Cldr.Calendar.Julian.day_of_week/4","doc":"Calculates the day of the week from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.Julian.html#day_of_week/4"},{"type":"function","title":"Cldr.Calendar.Julian.day_of_year/3","doc":"Calculates the day of the year from the given `year`, `month`, and `day`.","ref":"Cldr.Calendar.Julian.html#day_of_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.days_in_month/1","doc":"Returns how many days there are in the given month.\n\nIf the days in month cannot be determined without\nknowning the year an error tuple is returned.","ref":"Cldr.Calendar.Julian.html#days_in_month/1"},{"type":"function","title":"Cldr.Calendar.Julian.days_in_month/2","doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.Julian.html#days_in_month/2"},{"type":"function","title":"Cldr.Calendar.Julian.days_in_week/0","doc":"Returns the number days in a a week.","ref":"Cldr.Calendar.Julian.html#days_in_week/0"},{"type":"function","title":"Cldr.Calendar.Julian.days_in_year/1","doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.Julian.html#days_in_year/1"},{"type":"function","title":"Cldr.Calendar.Julian.epoch/0","doc":"","ref":"Cldr.Calendar.Julian.html#epoch/0"},{"type":"function","title":"Cldr.Calendar.Julian.extended_year/3","doc":"Returns the extended year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Julian.html#extended_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.iso_week_of_year/3","doc":"Calculates the ISO week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.Julian.html#iso_week_of_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.leap_year?/1","doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.Julian.html#leap_year?/1"},{"type":"type","title":"Cldr.Calendar.Julian.month/0","doc":"","ref":"Cldr.Calendar.Julian.html#t:month/0"},{"type":"function","title":"Cldr.Calendar.Julian.month/2","doc":"Returns a `Date.Range.t` representing\na given month of a year.","ref":"Cldr.Calendar.Julian.html#month/2"},{"type":"function","title":"Cldr.Calendar.Julian.month_of_year/3","doc":"Calculates the month of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 12.","ref":"Cldr.Calendar.Julian.html#month_of_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.naive_datetime_from_iso_days/1","doc":"Converts the `t:Calendar.iso_days/0` format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.Julian.html#naive_datetime_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.Julian.naive_datetime_to_iso_days/7","doc":"Returns the `t:Calendar.iso_days/0` format of the specified date.","ref":"Cldr.Calendar.Julian.html#naive_datetime_to_iso_days/7"},{"type":"function","title":"Cldr.Calendar.Julian.periods_in_year/1","doc":"Calculates the number of period in a given `year`. A period\ncorresponds to a month in month-based calendars and\na week in week-based calendars..","ref":"Cldr.Calendar.Julian.html#periods_in_year/1"},{"type":"function","title":"Cldr.Calendar.Julian.plus/6","doc":"Adds an `increment` number of `date_part`s\nto a `year-month-day`.\n\n`date_part` can be `:quarters`\n or`:months`.","ref":"Cldr.Calendar.Julian.html#plus/6"},{"type":"function","title":"Cldr.Calendar.Julian.quarter/2","doc":"Returns a `Date.Range.t` representing\na given quarter of a year.","ref":"Cldr.Calendar.Julian.html#quarter/2"},{"type":"function","title":"Cldr.Calendar.Julian.quarter_of_year/3","doc":"Calculates the quarter of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 4.","ref":"Cldr.Calendar.Julian.html#quarter_of_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.related_gregorian_year/3","doc":"Returns the related gregorian year as displayed\non rendered calendars.","ref":"Cldr.Calendar.Julian.html#related_gregorian_year/3"},{"type":"function","title":"Cldr.Calendar.Julian.shift_date/4","doc":"Shifts a date by given duration.","ref":"Cldr.Calendar.Julian.html#shift_date/4"},{"type":"function","title":"Cldr.Calendar.Julian.shift_naive_datetime/8","doc":"Shifts a naive date time by given duration.","ref":"Cldr.Calendar.Julian.html#shift_naive_datetime/8"},{"type":"function","title":"Cldr.Calendar.Julian.shift_time/5","doc":"Shifts a time by given duration.","ref":"Cldr.Calendar.Julian.html#shift_time/5"},{"type":"function","title":"Cldr.Calendar.Julian.valid_date?/3","doc":"Determines if the date given is valid according to this calendar.","ref":"Cldr.Calendar.Julian.html#valid_date?/3"},{"type":"function","title":"Cldr.Calendar.Julian.week/2","doc":"Returns a `Date.Range.t` representing\na given week of a year.","ref":"Cldr.Calendar.Julian.html#week/2"},{"type":"function","title":"Cldr.Calendar.Julian.week_of_month/3","doc":"Calculates the week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.Julian.html#week_of_month/3"},{"type":"function","title":"Cldr.Calendar.Julian.week_of_year/3","doc":"Calculates the week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.Julian.html#week_of_year/3"},{"type":"type","title":"Cldr.Calendar.Julian.year/0","doc":"","ref":"Cldr.Calendar.Julian.html#t:year/0"},{"type":"function","title":"Cldr.Calendar.Julian.year/1","doc":"Returns a `Date.Range.t` representing\na given year.","ref":"Cldr.Calendar.Julian.html#year/1"},{"type":"function","title":"Cldr.Calendar.Julian.year_of_era/1","doc":"Calculates the year and era from the given `year`.\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.Julian.html#year_of_era/1"},{"type":"function","title":"Cldr.Calendar.Julian.year_of_era/3","doc":"Calculates the year and era from the given `year`,\n`month` and `day`.","ref":"Cldr.Calendar.Julian.html#year_of_era/3"},{"type":"module","title":"Cldr.Calendar.Kday","doc":"Provide K-Day functions for Dates, DateTimes and NaiveDateTimes.","ref":"Cldr.Calendar.Kday.html"},{"type":"function","title":"Cldr.Calendar.Kday.first_kday/2","doc":"Return the date of the first `day_of_week` on or after the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#first_kday/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.first_kday/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n* `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#first_kday/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.first_kday/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Cldr.Calendar.Kday.html#first_kday/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.first_kday/2","doc":"# US election day\n    iex> Cldr.Calendar.Kday.first_kday(~D[2017-11-02], 2)\n    ~D[2017-11-07]\n\n    # US Daylight savings end\n    iex> Cldr.Calendar.Kday.first_kday(~D[2017-11-01], 7)\n    ~D[2017-11-05]","ref":"Cldr.Calendar.Kday.html#first_kday/2-examples"},{"type":"function","title":"Cldr.Calendar.Kday.kday_after/2","doc":"Return the date of the `day_of_week` after the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#kday_after/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.kday_after/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n* `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#kday_after/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.kday_after/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Cldr.Calendar.Kday.html#kday_after/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.kday_after/2","doc":"iex> Cldr.Calendar.Kday.kday_after(~D[2016-02-29], 2)\n    ~D[2016-03-01]\n\n    iex> Cldr.Calendar.Kday.kday_after(~D[2017-11-30], 1)\n    ~D[2017-12-04]\n\n    iex> Cldr.Calendar.Kday.kday_after(~D[2017-06-30], 6)\n    ~D[2017-07-01]\n\n    iex> Cldr.Calendar.Kday.kday_after(~D[2021-03-28], 7)\n    ~D[2021-04-04]","ref":"Cldr.Calendar.Kday.html#kday_after/2-examples"},{"type":"function","title":"Cldr.Calendar.Kday.kday_before/2","doc":"Return the date of the `day_of_week` before the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#kday_before/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.kday_before/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n* `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#kday_before/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.kday_before/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Cldr.Calendar.Kday.html#kday_before/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.kday_before/2","doc":"iex> Cldr.Calendar.Kday.kday_before(~D[2016-02-29], 2)\n    ~D[2016-02-23]\n\n    iex> Cldr.Calendar.Kday.kday_before(~D[2017-11-30], 1)\n    ~D[2017-11-27]\n\n    iex> Cldr.Calendar.Kday.kday_before(~D[2023-09-30], 5)\n    ~D[2023-09-29]\n\n    # 6 means Saturday.  Use either the integer value or the atom form.\n    iex> Cldr.Calendar.Kday.kday_before(~D[2017-06-30], 6)\n    ~D[2017-06-24]","ref":"Cldr.Calendar.Kday.html#kday_before/2-examples"},{"type":"function","title":"Cldr.Calendar.Kday.kday_nearest/2","doc":"Return the date of the `day_of_week` nearest the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#kday_nearest/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.kday_nearest/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n* `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#kday_nearest/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.kday_nearest/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Cldr.Calendar.Kday.html#kday_nearest/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.kday_nearest/2","doc":"iex> Cldr.Calendar.Kday.kday_nearest(~D[2016-02-29], 2)\n    ~D[2016-03-01]\n\n    iex> Cldr.Calendar.Kday.kday_nearest(~D[2017-11-30], 1)\n    ~D[2017-11-27]\n\n    iex> Cldr.Calendar.Kday.kday_nearest(~D[2017-06-30], 6)\n    ~D[2017-07-01]","ref":"Cldr.Calendar.Kday.html#kday_nearest/2-examples"},{"type":"function","title":"Cldr.Calendar.Kday.kday_on_or_after/2","doc":"Return the date of the `day_of_week` on or after the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#kday_on_or_after/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.kday_on_or_after/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n  * `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#kday_on_or_after/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.kday_on_or_after/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Cldr.Calendar.Kday.html#kday_on_or_after/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.kday_on_or_after/2","doc":"iex> Cldr.Calendar.Kday.kday_on_or_after(~D[2016-02-29], 2)\n    ~D[2016-03-01]\n\n    iex> Cldr.Calendar.Kday.kday_on_or_after(~D[2017-11-30], 1)\n    ~D[2017-12-04]\n\n    iex> Cldr.Calendar.Kday.kday_on_or_after(~D[2017-06-30], 6)\n    ~D[2017-07-01]\n\n    iex> Cldr.Calendar.Kday.kday_on_or_after(~D[2023-09-29], 5)\n    ~D[2023-09-29]","ref":"Cldr.Calendar.Kday.html#kday_on_or_after/2-examples"},{"type":"function","title":"Cldr.Calendar.Kday.kday_on_or_before/2","doc":"Return the date of the `day_of_week` on or before the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#kday_on_or_before/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.kday_on_or_before/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n  * `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#kday_on_or_before/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.kday_on_or_before/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Cldr.Calendar.Kday.html#kday_on_or_before/2-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.kday_on_or_before/2","doc":"iex> Cldr.Calendar.Kday.kday_on_or_before(~D[2016-02-29], 2)\n    ~D[2016-02-23]\n\n    iex> Cldr.Calendar.Kday.kday_on_or_before(~D[2017-11-30], 1)\n    ~D[2017-11-27]\n\n    iex> Cldr.Calendar.Kday.kday_on_or_before(~D[2017-06-30], 6)\n    ~D[2017-06-24]\n\n    iex> Cldr.Calendar.Kday.kday_on_or_before(~D[2023-09-29], 5)\n    ~D[2023-09-29]","ref":"Cldr.Calendar.Kday.html#kday_on_or_before/2-examples"},{"type":"function","title":"Cldr.Calendar.Kday.last_kday/2","doc":"Return the date of the last `day_of_week` on or before the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#last_kday/2"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.last_kday/2","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n* `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#last_kday/2-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.last_kday/2","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument","ref":"Cldr.Calendar.Kday.html#last_kday/2-returns"},{"type":"function","title":"Example - Cldr.Calendar.Kday.last_kday/2","doc":"# Memorial Day in the US\n    iex> Cldr.Calendar.Kday.last_kday(~D[2017-05-31], 1)\n    ~D[2017-05-29]","ref":"Cldr.Calendar.Kday.html#last_kday/2-example"},{"type":"function","title":"Cldr.Calendar.Kday.nth_kday/3","doc":"Return the date of the `nth` `day_of_week` on or before/after the\nspecified `date`.","ref":"Cldr.Calendar.Kday.html#nth_kday/3"},{"type":"function","title":"Arguments - Cldr.Calendar.Kday.nth_kday/3","doc":"* `date` is `t:Date.t/0`, a `t:DateTime.t/0`, `t:NaiveDateTime.t/0` or\n  ISO days since epoch.\n\n* `n` is the cardinal number of `k` before (negative `n`) or after\n  (positive `n`) the specified date.\n\n* `k` is an integer day of the week where `1` is\n  Monday and `7` is Sunday.","ref":"Cldr.Calendar.Kday.html#nth_kday/3-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Kday.nth_kday/3","doc":"* A `t:Date.t/0` in the calendar of the date provided as an argument.","ref":"Cldr.Calendar.Kday.html#nth_kday/3-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Kday.nth_kday/3","doc":"# Thanksgiving in the US\n    iex> Cldr.Calendar.Kday.nth_kday(~D[2017-11-01], 4, 4)\n    ~D[2017-11-23]\n\n    # Labor day in the US\n    iex> Cldr.Calendar.Kday.nth_kday(~D[2017-09-01], 1, 1)\n    ~D[2017-09-04]\n\n    # Daylight savings time starts in the US\n    iex> Cldr.Calendar.Kday.nth_kday(~D[2017-03-01], 2, 7)\n    ~D[2017-03-12]","ref":"Cldr.Calendar.Kday.html#nth_kday/3-examples"},{"type":"module","title":"Cldr.Calendar.NRF","doc":"Implements the US National Retail Federation\n(NRF) calendar.\n\nThe NRF calendar is defined to end on the\nlast Saturday of January.\n\nThis week-based approach allows for easier\ncomparison of seasonal business performance\nwith most US seasonal holidays falling into\nthe same week of the year.","ref":"Cldr.Calendar.NRF.html"},{"type":"function","title":"Cldr.Calendar.NRF.add/9","doc":"Adds a :year, :month, :day or time increments\n\nThese functions support CalendarInterval","ref":"Cldr.Calendar.NRF.html#add/9"},{"type":"function","title":"Cldr.Calendar.NRF.calendar_base/0","doc":"Identifies that the calendar is week based.","ref":"Cldr.Calendar.NRF.html#calendar_base/0"},{"type":"function","title":"Cldr.Calendar.NRF.calendar_year/3","doc":"Returns the calendar year as displayed\non rendered calendars.","ref":"Cldr.Calendar.NRF.html#calendar_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.cldr_calendar_type/0","doc":"Defines the CLDR calendar type for this calendar.\n\nThis type is used in support of `Cldr.Calendar.localize/3`.\nCurrently only `:gregorian` is supported.","ref":"Cldr.Calendar.NRF.html#cldr_calendar_type/0"},{"type":"function","title":"Cldr.Calendar.NRF.cyclic_year/3","doc":"Returns the cyclic year as displayed\non rendered calendars.","ref":"Cldr.Calendar.NRF.html#cyclic_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.date_from_iso_days/1","doc":"Returns `{year, month, day}` calculated from\nthe number of `iso_days`.","ref":"Cldr.Calendar.NRF.html#date_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.NRF.date_to_iso_days/3","doc":"Returns the number of days since the calendar\nepoch for a given `year-month-day`","ref":"Cldr.Calendar.NRF.html#date_to_iso_days/3"},{"type":"function","title":"Cldr.Calendar.NRF.day_of_era/3","doc":"Calculates the day and era from the given `year`, `month`, and `day`.","ref":"Cldr.Calendar.NRF.html#day_of_era/3"},{"type":"function","title":"Cldr.Calendar.NRF.day_of_week/4","doc":"Calculates the day of the week from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 7, where 1 is Monday and 7 is Sunday.","ref":"Cldr.Calendar.NRF.html#day_of_week/4"},{"type":"function","title":"Cldr.Calendar.NRF.day_of_year/3","doc":"Calculates the day of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 366.","ref":"Cldr.Calendar.NRF.html#day_of_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.days_in_month/1","doc":"Returns how many days there are in the given month.\n\nIf the days in month cannot be determined without\nknowning the year and error tuple is returned.","ref":"Cldr.Calendar.NRF.html#days_in_month/1"},{"type":"function","title":"Cldr.Calendar.NRF.days_in_month/2","doc":"Returns how many days there are in the given year-month.","ref":"Cldr.Calendar.NRF.html#days_in_month/2"},{"type":"function","title":"Cldr.Calendar.NRF.days_in_week/0","doc":"Returns the number days in a a week.","ref":"Cldr.Calendar.NRF.html#days_in_week/0"},{"type":"function","title":"Cldr.Calendar.NRF.days_in_year/1","doc":"Returns the number days in a given year.","ref":"Cldr.Calendar.NRF.html#days_in_year/1"},{"type":"function","title":"Cldr.Calendar.NRF.extended_year/3","doc":"Returns the extended year as displayed\non rendered calendars.","ref":"Cldr.Calendar.NRF.html#extended_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.first_gregorian_day_of_year/1","doc":"Returns the number of `iso_days` that is\nthe first day of the given\nyear for this calendar.","ref":"Cldr.Calendar.NRF.html#first_gregorian_day_of_year/1"},{"type":"function","title":"Cldr.Calendar.NRF.iso_week_of_year/3","doc":"Calculates the ISO week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.NRF.html#iso_week_of_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.last_gregorian_day_of_year/1","doc":"Returns the number of `iso_days` that is\nthe last day of the given\nyear for this calendar.","ref":"Cldr.Calendar.NRF.html#last_gregorian_day_of_year/1"},{"type":"function","title":"Cldr.Calendar.NRF.leap_year?/1","doc":"Returns if the given year is a leap year.","ref":"Cldr.Calendar.NRF.html#leap_year?/1"},{"type":"function","title":"Cldr.Calendar.NRF.month/2","doc":"Returns a `Date.Range.t` representing\na given month of a year.","ref":"Cldr.Calendar.NRF.html#month/2"},{"type":"function","title":"Cldr.Calendar.NRF.month_of_year/3","doc":"Calculates the month of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 12.","ref":"Cldr.Calendar.NRF.html#month_of_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.naive_datetime_from_iso_days/1","doc":"Converts the `t:Calendar.iso_days/0` format to the datetime format specified by this calendar.","ref":"Cldr.Calendar.NRF.html#naive_datetime_from_iso_days/1"},{"type":"function","title":"Cldr.Calendar.NRF.naive_datetime_to_iso_days/7","doc":"Returns the `t:Calendar.iso_days/0` format of the specified date.","ref":"Cldr.Calendar.NRF.html#naive_datetime_to_iso_days/7"},{"type":"function","title":"Cldr.Calendar.NRF.periods_in_year/1","doc":"Calculates the number of period in a given `year`. A period\ncorresponds to a month in month-based calendars and\na week in week-based calendars..","ref":"Cldr.Calendar.NRF.html#periods_in_year/1"},{"type":"function","title":"Cldr.Calendar.NRF.plus/6","doc":"Adds an `increment` number of `date_part`s\nto a `year-month-day`.\n\n`date_part` can be `:years`, `:quarters`,\n`:months` or `days`.","ref":"Cldr.Calendar.NRF.html#plus/6"},{"type":"function","title":"Cldr.Calendar.NRF.quarter/2","doc":"Returns a `Date.Range.t` representing\na given quarter of a year.","ref":"Cldr.Calendar.NRF.html#quarter/2"},{"type":"function","title":"Cldr.Calendar.NRF.quarter_of_year/3","doc":"Calculates the quarter of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 4.","ref":"Cldr.Calendar.NRF.html#quarter_of_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.related_gregorian_year/3","doc":"Returns the related gregorian year as displayed\non rendered calendars.","ref":"Cldr.Calendar.NRF.html#related_gregorian_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.shift_date/4","doc":"Shifts a date by given duration.","ref":"Cldr.Calendar.NRF.html#shift_date/4"},{"type":"function","title":"Cldr.Calendar.NRF.shift_naive_datetime/8","doc":"Shifts a naive date time by given duration.","ref":"Cldr.Calendar.NRF.html#shift_naive_datetime/8"},{"type":"function","title":"Cldr.Calendar.NRF.shift_time/5","doc":"Shifts a time by given duration.","ref":"Cldr.Calendar.NRF.html#shift_time/5"},{"type":"function","title":"Cldr.Calendar.NRF.valid_date?/3","doc":"Determines if the date given is valid according to the this calendar.","ref":"Cldr.Calendar.NRF.html#valid_date?/3"},{"type":"function","title":"Cldr.Calendar.NRF.week/2","doc":"Returns a `Date.Range.t` representing\na given week of a year.","ref":"Cldr.Calendar.NRF.html#week/2"},{"type":"function","title":"Cldr.Calendar.NRF.week_of_month/3","doc":"Calculates the week of the month from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 5.","ref":"Cldr.Calendar.NRF.html#week_of_month/3"},{"type":"function","title":"Cldr.Calendar.NRF.week_of_year/3","doc":"Calculates the week of the year from the given `year`, `month`, and `day`.\nIt is an integer from 1 to 53.","ref":"Cldr.Calendar.NRF.html#week_of_year/3"},{"type":"function","title":"Cldr.Calendar.NRF.weeks_in_year/1","doc":"Returns the number weeks in a given year.","ref":"Cldr.Calendar.NRF.html#weeks_in_year/1"},{"type":"function","title":"Arguments - Cldr.Calendar.NRF.weeks_in_year/1","doc":"* `year` is any `t:Calendar.year/0`","ref":"Cldr.Calendar.NRF.html#weeks_in_year/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.NRF.weeks_in_year/1","doc":"* `{weeks_in_year, days_in_last_week}`","ref":"Cldr.Calendar.NRF.html#weeks_in_year/1-returns"},{"type":"function","title":"Example - Cldr.Calendar.NRF.weeks_in_year/1","doc":"iex> Cldr.Calendar.ISOWeek.weeks_in_year 2020\n    {53, 7}\n\n    iex> Cldr.Calendar.ISOWeek.weeks_in_year 2021\n    {52, 7","ref":"Cldr.Calendar.NRF.html#weeks_in_year/1-example"},{"type":"function","title":"Cldr.Calendar.NRF.year/1","doc":"Returns a `Date.Range.t` representing\na given year.","ref":"Cldr.Calendar.NRF.html#year/1"},{"type":"function","title":"Cldr.Calendar.NRF.year_of_era/1","doc":"Calculates the year and era from the given `year`.\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.NRF.html#year_of_era/1"},{"type":"function","title":"Cldr.Calendar.NRF.year_of_era/3","doc":"Calculates the year and era from the given `year`,\n`month` and `day`.\n\nThe ISO calendar has two eras: the current era which\nstarts in year 1 and is defined as era \"1\". And a\nsecond era for those years less than 1 defined as\nera \"0\".","ref":"Cldr.Calendar.NRF.html#year_of_era/3"},{"type":"module","title":"Cldr.Calendar.Preference","doc":"","ref":"Cldr.Calendar.Preference.html"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_for_locale/1","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_for_locale/1"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_for_territory/1","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_for_territory/1"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_from_locale/1","doc":"Return the calendar module for a locale.","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Preference.calendar_from_locale/1","doc":"* `:locale` is any locale or locale name validated\n  by `Cldr.validate_locale/2`.  The default is\n  `Cldr.get_locale()` which returns the locale\n  set for the current process.","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Preference.calendar_from_locale/1","doc":"* `{:ok, calendar_module}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Preference.calendar_from_locale/1","doc":"iex> Cldr.Calendar.Preference.calendar_from_locale(:\"en-GB\")\n    {:ok, Cldr.Calendar.GB}\n\n    iex> Cldr.Calendar.Preference.calendar_from_locale(\"en-GB-u-ca-gregory\")\n    {:ok, Cldr.Calendar.Gregorian}\n\n    iex> Cldr.Calendar.Preference.calendar_from_locale(:en)\n    {:ok, Cldr.Calendar.US}\n\n    iex> Cldr.Calendar.Preference.calendar_from_locale(:\"fa-IR\")\n    {:ok, Cldr.Calendar.Persian}\n\n    iex> Cldr.Calendar.Preference.calendar_from_locale(\"fa-IR-u-ca-gregory\")\n    {:ok, Cldr.Calendar.Gregorian}","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/1-examples"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_from_locale/2","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_from_locale/2"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_from_name/1","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_from_name/1"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_from_territory/1","doc":"Returns the calendar module preferred for\na territory.","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/1"},{"type":"function","title":"Arguments - Cldr.Calendar.Preference.calendar_from_territory/1","doc":"* `territory` is any valid ISO3166-2 code as\n  an `String.t` or upcased `atom()`","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/1-arguments"},{"type":"function","title":"Returns - Cldr.Calendar.Preference.calendar_from_territory/1","doc":"* `{:ok, calendar_module}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/1-returns"},{"type":"function","title":"Examples - Cldr.Calendar.Preference.calendar_from_territory/1","doc":"iex> Cldr.Calendar.Preference.calendar_from_territory :US\n    {:ok, Cldr.Calendar.US}\n\n    iex> Cldr.Calendar.Preference.calendar_from_territory :YY\n    {:error, {Cldr.UnknownTerritoryError, \"The territory :YY is unknown\"}}","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/1-examples"},{"type":"function","title":"Notes - Cldr.Calendar.Preference.calendar_from_territory/1","doc":"The overwhelming majority of territories have\n`:gregorian` as their first preferred calendar\nand therefore `Cldr.Calendar.Gregorian`\nwill be returned for most territories.\n\nReturning any other calendar module would require:\n\n1. That another calendar is preferred over `:gregorian`\n   for a territory\n\n2. That a calendar module is available to support\n   that calendar.\n\nAs an example, Iran (territory `:IR`) prefers the\n`:persian` calendar. If the optional library\n[ex_cldr_calendars_persian](https://hex.pm/packages/ex_cldr_calendars_persian)\nis installed, the calendar module `Cldr.Calendar.Persian` will\nbe returned. If it is not installed, `Cldr.Calendar.Gregorian`\nwill be returned as `:gregorian` is the second preference\nfor `:IR`.","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/1-notes"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_from_territory/2","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_from_territory/2"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_module/1","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_module/1"},{"type":"function","title":"Cldr.Calendar.Preference.calendar_modules/0","doc":"","ref":"Cldr.Calendar.Preference.html#calendar_modules/0"},{"type":"module","title":"Cldr.Calendar.Sigils","doc":"Implements the `~d` sigils to produce\ndates, datetimes and naive datetimes.","ref":"Cldr.Calendar.Sigils.html"},{"type":"function","title":"Cldr.Calendar.Sigils.do_sigil_d/2","doc":"","ref":"Cldr.Calendar.Sigils.html#do_sigil_d/2"},{"type":"macro","title":"Cldr.Calendar.Sigils.sigil_d/2","doc":"Implements a ~d sigil for expressing dates.\n\nDates can be expressed in the following formats:\n\n* `~d[yyyy-mm-dd]` which produces a date in the `Cldr.Calendar.Gregorian` calendar\n* `~d[yyyy-Wmm-dd]` which produces a date in the `Cldr.Calendar.ISOWeek` calendar\n* `~d[yyyy-mm-dd calendar]` which produces a date in the given month-based calendar\n* `~d[yyyy-Wmm-dd calendar]` which produces a date in the given week-based calendar\n* `~d[yyyy-mm-dd C.E Julian]` which produces a date in the Cldr.Calendar.Julian calendar\n* `~d[yyyy-mm-dd B.C.E Julian]` which produces a date in the Cldr.Calendar.Julian calendar","ref":"Cldr.Calendar.Sigils.html#sigil_d/2"},{"type":"macro","title":"Examples - Cldr.Calendar.Sigils.sigil_d/2","doc":"iex> import Cldr.Calendar.Sigils\n    iex> ~d[2019-01-01 Gregorian]\n    ~d[2019-01-01 Gregorian]\n    iex> ~d[2019-W01-01]\n    ~d[2019-W01-1 ISOWeek]","ref":"Cldr.Calendar.Sigils.html#sigil_d/2-examples"},{"type":"exception","title":"Cldr.IncompatibleCalendarError","doc":"Exception raised when an attempt is made to use a two incompatible\ncalendars.","ref":"Cldr.IncompatibleCalendarError.html"},{"type":"exception","title":"Cldr.IncompatibleTimeZone","doc":"Exception raised when a two datestimes\nare not in the same timezone","ref":"Cldr.IncompatibleTimeZone.html"},{"type":"exception","title":"Cldr.InvalidCalendarModule","doc":"Exception raised when a module is not a\ncalendar.","ref":"Cldr.InvalidCalendarModule.html"},{"type":"exception","title":"Cldr.InvalidDateOrder","doc":"Exception raised when two dates\nor times are not ordered from earlier\nto later","ref":"Cldr.InvalidDateOrder.html"},{"type":"exception","title":"Cldr.MissingFields","doc":"Exception raised when the provided\ndate does not have the required fields\nfor a function.","ref":"Cldr.MissingFields.html"},{"type":"extras","title":"Cldr Calendars","doc":"# Cldr Calendars\n\n![Build status](https://github.com/elixir-cldr/cldr_calendars/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr_calendars.svg)](https://hex.pm/packages/ex_cldr_calendars)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr_calendars.svg?)](https://hex.pm/packages/ex_cldr_calendars)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_cldr_calendars.svg?)](https://hex.pm/packages/ex_cldr_calendars)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr_calendars.svg)](https://hex.pm/packages/ex_cldr_calendars)\n\n> My wife's jealousy is getting ridiculous. The other day she looked at my calendar and wanted to know who May was.\n> -- Rodney Dangerfield\n\n# Introduction\n\nCalendars are curious things. For centuries people from all cultures have sought to impose human order on the astronomical movements of the earth and moon. Today, despite much of the world converging on the [Proleptic Gregorian](https://en.wikipedia.org/wiki/Proleptic_Gregorian_calendar) calendar, there remain many derivative and alternative ways for humans to organise the passage of time.\n\n`Cldr Calendars` builds on Elixir's standard `Calendar` module to provide additional calendars and calendar functionality intended to be of practical use.  In particular `Cldr Calendars`:\n\n* Provides support for configurable month-based and week-based calendars that are in common use as [Fiscal Year](https://en.wikipedia.org/wiki/Fiscal_year) calendars for countries and organizations around the world. See `Cldr.Calendar.new/3`\n\n* Supports localisation of common calendar terms such as *day of the week* and *month of the year* using the [CLDR](https://cldr.unicode.org) data that is available for over 500 locales. See `Cldr.Calendar.localize/3`\n\n* Supports locale-specific knowledge of what is a weekend or a workday. See `Cldr.Calendar.weekend/1`, `Cldr.Calendar.weekend?/2`, `Cldr.Calendar.weekdays/1` and `Cldr.Calendar.weekday?/2`.\n\n* Provides convenient `Date.Range` calculators for years, quarters, months and weeks for calendars and provides the means to move to the `next` and `previous` period in a calendar where a period may be a year, quarter, month, week or day.\n\n* Supports adding or subtracting periods to dates and date ranges. See `Cldr.Calendar.plus/3` and `Cldr.Calendar.minus/3`\n\n* Includes pre-defined calendars for Gregorian (compatible with the builtin `Calendar` module), `ISOWeek` and `National Retail Federation (NRF)` calendars\n\n* Includes returning a calendar configured to reflect the `first_day_of_week` and `min_days_in_first_week` for a given territory lor locale.  See `Cldr.Calendar.calendar_for_locale/2`.\n\n* Includes functions to find the first, last, nearest and `nth` days of the week from a date. For example, find the `2nd Tuesday in November`.\n\n**See the documentation for `Cldr.Calendar` for the main public API.**","ref":"readme.html"},{"type":"extras","title":"Cldr Calendars Installation - Cldr Calendars","doc":"Add `ex_cldr_calendars` to your `deps` in `mix.exs`. **Note that `ex_cldr_calendars` is supported on Elixir 1.11 and later only**.\n\n```elixir\ndef deps do\n  [\n    {:ex_cldr_calendars, \"~> 1.26\"}\n    ...\n  ]\nend\n```","ref":"readme.html#cldr-calendars-installation"},{"type":"extras","title":"Getting Started - Cldr Calendars","doc":"Let's say you work for [Cisco Systems](https://cisco.com). Your learn that the financial year ends on the last Saturday of July. To make things easy you'd like to compare the results of this financial year to last finanical year.  And you'd like to know how many days are left this quarter in order to achieve your sales targets.\n\nHere's how we do that:","ref":"readme.html#getting-started"},{"type":"extras","title":"Define a calendar that represents Cisco's financial year - Cldr Calendars","doc":"Each calendar is defined as a module that implements both the `Calendar` and `Cldr.Calendar` behaviours.  The details of how that is achieved isn't important at this stage.  Its easy to define your own calendar module through some configuration parameters.  Here's how we do that for Cisco:\n```\ndefmodule Cldr.Calendar.CSCO do\n  use Cldr.Calendar.Base.Week,\n    first_or_last: :last,\n    day_of_year_: 6,\n    month_of_year_: 7\nend\n```\nThis configuration says that the calendar is defined as `first_or_last: :last` which means we are defining a calendar in terms of when it ends (you can of course also define a calendar in terms of when it starts by setting this to `:first`).\n\nThe `:day_of_year` day is Saturday, which is in `Calendar` speak, the sixth day of the week.  Days of the week are numbered from `1` for Monday to `7` to Sunday.\n\nThe `:month_of_year` is July.  Months are numbered from January being `1` to December being `12`.\n\nThere we have it, a calendar that is based upon the definition of \"ends on the last Saturday of July\".","ref":"readme.html#define-a-calendar-that-represents-cisco-s-financial-year"},{"type":"extras","title":"Dates in Cisco's calendar - Cldr Calendars","doc":"You might be wondering, how to we represent dates in a customised calendar like this? Thanks to the flexibility of Elixir's standard `Calendar` module, we can leverage existing functions to build a date.  Lets build a date which is the first day of Cisco's financial year for 2019.\n```\n{:ok, date} = Date.new(2019, 1, 1, Cldr.Calendar.CSCO)\n{:ok, ~d[2019-W01-1 CSCO]}\n```\nThat was easy.  All dates are specified *in the context of the specific calendar*.  We don't need to know what the equivalent Gregorian calendar date is.  But we can find out if we want to:\n```\niex> Date.convert date, Calendar.ISO\n{:ok, ~D[2018-07-29]}\n```\nWhich you will see is July 29th, 2018 - a Sunday.  Since we specified that the `:last` day of the year is a Saturday this makes sense.  You will also note that this is a date in 2018 as it should be. The year ends in July so it must start around 12 months earlier - in July of 2018.\n\nThis would also mean that the last day of Fiscal Year 2018 must be July 28th, 2018.  Lets check:\n```\niex> Cldr.Calendar.last_gregorian_day_of_year(2018, Cldr.Calendar.CSCO)\n~d[2018-07-28 Gregorian]\n```\nWhich you will see is the last Saturday in July for 2018.","ref":"readme.html#dates-in-cisco-s-calendar"},{"type":"extras","title":"Years, quarters, months, weeks and days - Cldr Calendars","doc":"A common activity with calendars is selecting data in certain date ranges or iterating over those same ranges. `Cldr Calendars` makes that easy.\n\nWant to know what is the first quarter of Cisco's financial year in 2019?\n```\n iex> range = Cldr.Calendar.Interval.quarter 2019, 1, Cldr.Calendar.CSCO\n #DateRange<~d[2019-W01-1 CSCO], ~d[2019-W13-7 CSCO]>\n```\nA `Date.Range.t` is returned which can be enumerated with any of Elixir's [Enum](https://hexdocs.pm/elixir/Enum.html) or [Stream](https://hexdocs.pm/elixir/Stream.html) functions. The same applies for `year`, `month`, `week` and `day`.\n\nLet's list all of the days Cisco's first quarter:\n```\niex> Enum.map range, &Cldr.Calendar.date_to_string/1\n[\"2019-W01-1\", \"2019-W01-2\", \"2019-W01-3\", \"2019-W01-4\", \"2019-W01-5\",\n \"2019-W01-6\", \"2019-W01-7\", \"2019-W02-1\", \"2019-W02-2\", \"2019-W02-3\",\n \"2019-W02-4\", \"2019-W02-5\", \"2019-W02-6\", \"2019-W02-7\", \"2019-W03-1\",\n \"2019-W03-2\", \"2019-W03-3\", \"2019-W03-4\", \"2019-W03-5\", \"2019-W03-6\",\n \"2019-W03-7\", \"2019-W04-1\", \"2019-W04-2\", \"2019-W04-3\", \"2019-W04-4\",\n \"2019-W04-5\", \"2019-W04-6\", \"2019-W04-7\", \"2019-W05-1\", \"2019-W05-2\",\n \"2019-W05-3\", \"2019-W05-4\", \"2019-W05-5\", \"2019-W05-6\", \"2019-W05-7\",\n \"2019-W06-1\", \"2019-W06-2\", \"2019-W06-3\", \"2019-W06-4\", \"2019-W06-5\",\n \"2019-W06-6\", \"2019-W06-7\", \"2019-W07-1\", \"2019-W07-2\", \"2019-W07-3\",\n \"2019-W07-4\", \"2019-W07-5\", \"2019-W07-6\", \"2019-W07-7\", \"2019-W08-1\", ...]\n```\nBut wait a minute, these don't look like familiar dates!  Shouldn't they be formatted as \"yyy-mm-dd\"? The answer in this case is \"no\".\n\nIf you look carefully at where we asked for the date range for Cisco's first quarter of 2019 you will see `%Date{calendar: Cldr.Calendar.CSCO, day: 7, month: 13, year: 2019}` as the last date in the range. There is, of course, no such month as `13` in the Gregorian calendar.  What's going on?","ref":"readme.html#years-quarters-months-weeks-and-days"},{"type":"extras","title":"Week-based calendars - Cldr Calendars","doc":"Cisco's calendar is an example of a \"week-based\" calendar. Such week-based calendars are examples of [fiscal year calendars](https://en.wikipedia.org/wiki/Fiscal_year). In `Cldr Calendar`, any calendar that is defined in terms of \"[first | last] [day_of_week] of [month_of_year_]\" is a week-based calendar.  These calendars have a year of 52 weeks duration except in \"leap years\" that have 53 weeks.\n\nThe most well-known week-based calendar may be the [ISO Week Calendar](https://en.wikipedia.org/wiki/ISO_week_date). How would we define that calendar in `Cldr Calendars`? Easy!\n```\ndefmodule Cldr.Calendar.ISOWeek do\n  use Cldr.Calendar.Base.Week,\n    day: 1,\n    min_days_in_first_week: 4\nend\n```\nThis says that the calendar starts on the first Monday in January. How do we know that?  It's because\n`:month_of_year` defaults to `1` (January) and `:first_or_last` defaults to `:first`.\n\nLets see what the first day of 2019 is in the `ISOWeek` calendar.\n```\niex> date = Cldr.Calendar.first_day_of_year(2019, Cldr.Calendar.ISOWeek)\n~d[2019-W01-1 ISOWeek]\n```\nAs expected, the date is expressed in terms of the calendar `Cldr.Calendar.ISOWeek`. What's the equivalent Gregorian day?\n```\niex> Date.convert(date, Calendar.ISO)\n{:ok, ~D[2018-12-31]}\n```\nThat's interesting.  The first day of the 2019 year in the ISO Week calendar is actually December 31st, 2018. Why is that?\n\nWeek-based calendars can start or end on a given day of the week in a given month.  But there is a third option: the given day of the week *nearest* to the start or end of the given month.  This is indicated by the configuration parameter `:min_days_in_first_week`.  For the `ISO Week` calendar we have `min_days_in_first_week: 4`.  That means that at least `4` days of the first or last week have to be in the specified `:month_of_year` and then we select the nearest day of the week.  Hence it is possible and even common for the gregorian start of the year for a week-based calendar to be up to 6 days before or after the Gregorian start of the year.\n\nWhat's the last week of 2019 in the `ISO Week` calendar?\n```\n iex> date = Cldr.Calendar.Interval.week(2019, 52, Cldr.Calendar.ISOWeek)\n #DateRange<~d[2019-W52-1 ISOWeek], ~d[2019-W52-7 ISOWeek]>\n```\nYou'll see that for week-based calendars the date is actually stored as `year, week, day` where the `:month` field of the `Date.t` is actually the week in the year and `:day` is the day in the week.","ref":"readme.html#week-based-calendars"},{"type":"extras","title":"Month-based calendars - Cldr Calendars","doc":"The Gregorian calendar is the canonical example of a month-based calendar. It starts on January 1st and ends on December 31st each year.  But not all calendars start in January and end in December.\n\n* The United States fiscal year starts on October 1st and ends on September 30th\n* The United Kingdom fiscal year starts on April 1st and ends on March 31st\n* The Australian fiscal year starts on July 1st and ends on June 30th\n\n`Cldr Calendars` allows month-based calendars to be defined based upon the first or last gregorian month of the year for that calendar.\n\nOf course sometimes we also want to refer to weeks within a year although this is less common than referring to days within months.  Nevertheless, a month-based calendar can also take advantage of `:first_day` and `:min_days` to determine how to calculate weeks for month-based calendars too.\n\nHere's how we define each of the three example calendars above:\n\n```\ndefmodule Cldr.Calendar.US do\n  use Cldr.Calendar.Base.Month,\n    month_of_year: 10,          # The year starts in October\n    min_days_in_first_week: 4,  # The first week of the year is that with at least 4 days of October in it\n    day_of_week: 7              # When referring to weeks, Sunday is the first day\nend\n\ndefmodule Cldr.Calendar.UK do\n  use Cldr.Calendar.Base.Month,\n    month_of_year: 4            # The fiscal year starts in April\nend\n\ndefmodule Cldr.Calendar.AU do\n  use Cldr.Calendar.Base.Month,\n    month_of_year: 7,           # The fiscal year starts in July\n    year: :ending               # A year refers to the ending Gregorian year.\n                                # In this example, the Australian fiscal\n                                # year 2017 is the year that starts in July\n                                # 2016 and ends in June 2017\nend\n```","ref":"readme.html#month-based-calendars"},{"type":"extras","title":"Beginning and ending gregorian years - Cldr Calendars","doc":"When we talk about the Gregorian calendar we refer to the 12 months from January to December. However when we consider the various fiscal calendars, the Gregorian starting date and the Gregorian ending date will often be in different years.\n\nIn these cases, when we say \"the 2019 US Fiscal Year\" what does that mean?  The US fiscal year starts in October. Now we need to know whether referring to the \"the 2019 US Fiscal Year\" means the year that ends in September 2019 or the year that starts in October 2019.\n\nSome further examples are:\n\n* The UK Fiscal Year starts in April. By convention, the Fiscal Year is the year that starts with April.\n\n* The US Fiscal Year starts in October.  By convention , the Fiscal Year is the year that has the ending October in it.\n\n* The Australian Fiscal Year starts in July. By convention, the Fiscal Year is the year that ends in July.\n\n* The National Retail Federation has a calendar that starts on the Saturday nearest the end of January.  By convention, the Fiscal Year is the year of the starting Saturday.\n\nTo cater for these varying definitions of what a Fiscal Year means, a configuration option `:year` can be set to `:majority` (which is the default), `:beginning` and `:ending`.\n\n* `:majority` means that the Fiscal Year is the year that has the most Gregorian months in it. This is the default.\n* `:beginning` means that the Fiscal Year is the year in which the first Gregorian month is found.\n* `:ending` means that the Fiscal Year is the year in which the last Gregorian month is found.\n\nFirst lets consider the default `:majority` strategy.  This strategy says that the Fiscal Year is that year in which the majority of Gregorian months are found.\n\n                            2018                      2019                      2020\n                  J F M A M J J A S O N D | J F M A M J J A S O N D | J F M A M J J A S O N D |\n                  . . . . . . . . . . . . | . . . . . . . . . . . . | . . . . . . . . . . . . |\n    Majority\n      Starts Jan                            <--------------------->\n      Starts Mar                                <----------------------->\n      Starts Jun                                      <----------------------->\n      Starts Jul              <----------------------->\n      Starts Oct                    <----------------------->\n\n      Ends Dec                              <--------------------->\n      Ends Feb                                  <----------------------->\n      Ends May                                        <----------------------->\n      Ends Jun                <----------------------->\n      Ends Aug                    <----------------------->\n\nFrom the diagram above we can define the following rules:\n\n* For `:starts` calendars, we can say that the *starting* gregorian year is is the same as the *fiscal year* if the starting month is January through June inclusive. If the starting month is July through to December then the starting Gregorian year is the year *prior* to the *fiscal year*. Similarly, the *ending* Gregorian year is the *next* year for calendars that start in February through June and it's the *fiscal year* for calendars that start in July through December. Years that start in January end in January of the same year.\n\n* For \":ends\" calendars the rules are the opposite.","ref":"readme.html#beginning-and-ending-gregorian-years"},{"type":"extras","title":"Calendar Creation - Cldr Calendars","doc":"Since calendars defined in `Cldr.Calendar` are intended to be compatible and convertible to other Calendars supporting Elixir's `Calendar` behaviour, the configuration of calendars needs to be encapsulated.\n\nThe simplest way to is to define a module that `use`s either `Cldr.Calendar.Base.Week` or `Cldr.Calendar.Base.Month`. This is how we have been defining calendar modules in the examples so far.\n\nA calendar module can also be created at run time.  It is semantically identical to defining a static module but the module is built at run time rather than compile time. New calendars are created with the function `Cldr.Calendar.new/3`. For example:\n```\niex> Cldr.Calendar.new :my_new_calendar, :week, first_or_last: :first, day_of_week: 1, min_days_in_first_week: 7\n{:ok, :my_new_calendar}\n```\nCalendar functions are now available on the module `:my_new_calendar`.\n```\niex> :my_new_calendar.\n__config__/0\ndate_from_iso_days/1\ndate_to_iso_days/3\ndate_to_string/3\ndatetime_to_string/11\nday_of_era/3\nday_of_week/3\nday_of_year/3\n...\n```\n\n**CAUTION** Since the runtime creation of new calendars creates a new module and therefore a new atom, this function has the potential to surface an attack vector that could exhaust the atom table and crash the BEAM.  It is strongly recommended calendars be defined statically where possible. Never trust unfiltered user input to create a calendar.","ref":"readme.html#calendar-creation"},{"type":"extras","title":"Fiscal Calendars for Territories - Cldr Calendars","doc":"`Cldr Calendars` can create a fiscal year calendar for many territories (countries) based upon data from [the CIA world fact book](https://www.cia.gov/library/publications/the-world-factbook/fields/228.html).  To create a fiscal year calendar for a territory use the `Cldr.Calendar.FiscalYear.calendar_for/1` function.\n\n```\n iex> Cldr.Calendar.FiscalYear.calendar_for(\"IS\")\n {:ok, Cldr.Calendar.FiscalYear.IS}\n\n iex> Cldr.Calendar.FiscalYear.calendar_for(\"ZZ\")\n {:error, {Cldr.UnknownTerritoryError, \"The territory \\\"ZZ\\\" is unknown\"}}\n\n iex> Cldr.Calendar.FiscalYear.calendar_for(:AF)\n {:error, {Cldr.UnknownCalendarError, \"Fiscal calendar is unknown for :AF\"}}\n```","ref":"readme.html#fiscal-calendars-for-territories"},{"type":"extras","title":"Sigil ~d - Cldr Calendars","doc":"`Cldr Calendars` provides a convenience sigil for the creation of dates in calendars. Note that it is necessary to import the `Cldr.Calendar.Sigils` module before using the `~d` sigil.\n```\n iex> import Cldr.Calendar.Sigils\n\n # Create a date in the default Cldr.Calendar.Gregorian\n iex> ~d[2019-01-01]\n ~d[2019-01-01 Gregorian]\n\n # Inbuilt calendars can be referred to by their shortened form\n iex> ~d[2019-01-01 NRF]\n ~d[2019-W01-1 NRF]\n\n # Create a calendar and define a date in it\n iex> Cldr.Calendar.new FiscalAU, :month, month_of_year: 7\n {:ok, FiscalAU}\n iex> ~d[2019-01-01 FiscalAU]\n ~d[2019-01-01 FiscalAU]\n ```","ref":"readme.html#sigil-d"},{"type":"extras","title":"Date localization - Cldr Calendars","doc":"`Cldr Calendars` is able to localize parts of a date include the `era`,\n`quarter`, `month` and `day_of_week`.  The [CLDR](htts://cldr.unicode.org)\nprovides the underlying data.  The function `Cldr.Calendar.localize/3`\nprovides the required functionality. Some examples are:\n```\n iex> Cldr.Calendar.localize ~D[2019-01-01], :era\n \"AD\"\n\n iex> Cldr.Calendar.localize ~D[2019-01-01], :day_of_week\n \"Tue\"\n\n iex> Cldr.Calendar.localize ~D[0001-01-01], :day_of_week\n \"Mon\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :era\n \"AD\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :quarter\n \"Q2\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :month\n \"Jun\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week\n \"Sat\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :wide\n \"Saturday\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, format: :narrow\n \"S\"\n\n iex> Cldr.Calendar.localize ~D[2019-06-01], :day_of_week, locale: \"ar\"\n      \"السبت\"\n```","ref":"readme.html#date-localization"},{"type":"extras","title":"Calendar Intervals (date ranges) - Cldr Calendars","doc":"Intervals representing parts of a calendar can be created and compared. Since intervals are represented as a `Date.Range` they can also be enumerated with the `Map` and `Stream` functions.\n\nIntervals can be created for a year, quarter, month, week and day.  For example:\n\n```elixir\n  iex> Cldr.Calendar.Interval.year(2019)\n  #DateRange<~d[2019-01-01 Gregorian], ~d[2019-12-31 Gregorian]>\n\n  iex> Cldr.Calendar.Interval.month(2019, 3)\n  #DateRange<~d[2019-03-01 Gregorian], ~d[2019-03-31 Gregorian]>\n\n  iex> Cldr.Calendar.Interval.month(2019, 3, Cldr.Calendar.NRF)\n  #DateRange<~d[2019-W10-1 NRF], ~d[2019-W13-7 NRF]>\n\n  iex> Cldr.Calendar.Interval.week(2019, 5, Cldr.Calendar.NRF)\n  #DateRange<~d[2019-W05-1 NRF], ~d[2019-W05-7 NRF]>\n\n  iex> Cldr.Calendar.Interval.quarter(2019, 3)\n  #DateRange<~d[2019-07-01 Gregorian], ~d[2019-09-30 Gregorian]>\n```","ref":"readme.html#calendar-intervals-date-ranges"},{"type":"extras","title":"Comparing Calendar Intervals - Cldr Calendars","doc":"Intervals can also be compared to each other and using the taxonomy of [Allen's Interval Algebra](https://en.wikipedia.org/wiki/Allen%27s_interval_algebra) a comparison will return one of 13 different relationship types between two calendar intervals:\n\n  Relation\t     | Inverse\n  ----------     | --------------\n  :precedes\t     | :preceded_by\n  :meets         | :met_by\n  :overlaps      | :overlapped_by\n  :finished_by   | :finishes\n  :contains      | :during\n  :starts        | :started_by\n  :equals        | :equals\n\nSome examples:\n\n```elixir\n  iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]),\n  ...> Cldr.Calendar.Interval.day(~D[2019-01-02])\n  :meets\n\n  iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-01]),\n  ...> Cldr.Calendar.Interval.day(~D[2019-01-03])\n  :precedes\n\n  iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-03]),\n  ...> Cldr.Calendar.Interval.day(~D[2019-01-01])\n  :preceded_by\n\n  iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]),\n  ...> Cldr.Calendar.Interval.day(~D[2019-01-01])\n  :met_by\n\n  iex> Cldr.Calendar.Interval.compare Cldr.Calendar.Interval.day(~D[2019-01-02]),\n  ...> Cldr.Calendar.Interval.day(~D[2019-01-02])\n  :equals\n```","ref":"readme.html#comparing-calendar-intervals"},{"type":"extras","title":"Durations - Cldr Calendars","doc":"A duration is calculated as the difference in time in calendar units: years, months, days, hours, minutes, seconds and microseconds.\n\nThis is useful to support formatting a string for users in easy-to-understand terms. For example `11 months, 3 days and 4 minutes` is a lot easier to understand than `28771440` seconds.\n\nThe package [ex_cldr_units](https://hex.pm/packages/ex_cldr_units) can be optionally configured to provide localized formatting of durations.\n\nIf configured, the following providers must be configured in the appropriate CLDR backend module. For example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"ja\"],\n    providers: [Cldr.Calendar, Cldr.Number, Cldr.Unit, Cldr.List]\nend\n```\n\nTo create a duration, use `Cldr.Calendar.Duration.new/2` providing two dates, times or datetimes. The first date must occur before the second date.  Datetimes must be in the same time zone. To format a duration into a string use `Cldr.Calendar.Duration.to_string/2`.\n\nAn example is:\n```elixir\niex> {:ok, duration} = Cldr.Calendar.Duration.new(~D[2019-01-01], ~D[2019-12-31])\niex> Cldr.Calendar.Duration.to_string(duration)\n\"11 months and 30 days\"\n```\n\nA duration can also be created from a `Date.Range.t` and `CalendarInterval.t`. `CalendarInterval.t` is defined by the wonderful [calendar_interval](https://hex.pm/packages/calendar_interval) library.\n\n```elixir\niex> Cldr.Calendar.Duration.new Date.range(~D[2020-01-01], ~D[2020-12-31])\n{:ok,\n %Cldr.Calendar.Duration{\n   day: 30,\n   hour: 0,\n   microsecond: 0,\n   minute: 0,\n   month: 11,\n   second: 0,\n   year: 0\n }}\n\niex> use CalendarInterval\nCalendarInterval\n\niex> Cldr.Calendar.Duration.new ~I\"2020-01/12\"\n{:ok,\n %Cldr.Calendar.Duration{\n   day: 30,\n   hour: 0,\n   microsecond: 0,\n   minute: 0,\n   month: 11,\n   second: 0,\n   year: 0\n }}\n```\n\nA duration can be added to a date. Adding to times and datetimes is not currently supported. An example is:\n\n```elixir\niex> {:ok, duration} = Cldr.Calendar.Duration.new(~D[2019-01-01], ~D[2019-12-31])\niex> Cldr.Calendar.plus ~D[2019-01-01], duration\n~D[2019-12-31]\n```","ref":"readme.html#durations"},{"type":"extras","title":"Configuring a Cldr backend for localization - Cldr Calendars","doc":"In order to localize date parts a `backend` module must be defined. This\nis a module which hosts the CLDR data for a set of locales. The detailed\ninformation for configuring a `backend` is [documented here](https://hexdocs.pm/ex_cldr/readme.html#configuration).\n\nFor a simple configuration the following steps may be used:\n\n1. Create a backend module.\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\", \"jp\", \"ar\"],\n    providers: [Cldr.Calendar, Cldr.Number]\nend\n```\n\n2. Optionally configure this backend as the system default in your `config.exs`.\n```\nconfig :ex_cldr,\n  default_backend: MyApp.Cldr\n```\n\n3. When creating a calendar a default backend may also be defined for this calendar.\n```\ndefmodule MyCalendar do\n  use Cldr.Calendar.Base.Month,\n    month_of_year: 4,\n    cldr_backend: MyApp.Cldr\nend\n```\n\nIt is also possible to pass the name of a backend module to the `Cldr.Calendar.localize/3` function by specifying the `:backend` option with a `backend` module name.","ref":"readme.html#configuring-a-cldr-backend-for-localization"},{"type":"extras","title":"Interesting calendar links - Cldr Calendars","doc":"* [Why isn’t the new year on the winter solstice?](https://slj.ma/cal.html)","ref":"readme.html#interesting-calendar-links"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2018-2019 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n**Note that `ex_cldr_calendars` version 1.24.0 and later are supported on Elixir 1.12 and later only.**","ref":"changelog.html"},{"type":"extras","title":"Cldr.Calendars v1.26.4 - Changelog","doc":"This is the changelog for Cldr Calendars v1.26.4 released on December 29th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-26-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix day of week calculations when the config `%{day_of_week: :first}` is set.\n\n* Improve the implementation of the fix for #23 to respect the conditional compilation based upon whether `ex_cldr_units` is configured or not.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.26.3 - Changelog","doc":"This is the changelog for Cldr Calendars v1.26.3 released on December 29th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-26-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix typing warning on Elixir 1.18. Thanks to @tjchambers for the report. Closes #23.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.26.2 - Changelog","doc":"This is the changelog for Cldr Calendars v1.26.2 released on September 12th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-26-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Calendar.Interval.compare/2` when the ranges overlap by one day. Thanks to @ArthurClemens for the report. Fixes #22.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.26.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.26.1 released on August 16th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-26-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix specs to suport dialyzer flags `:error_handling, :unknown, :underspecs, :extra_return, :missing_return`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.26.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.26.0 released on July 27th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-26-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Microseconds in `t:Cldr.Calendar.Duration.t/0` now follow the `t:Time.t/0` expectations.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.Duration.new_from_seconds/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr.Calendars v1.25.2 - Changelog","doc":"This is the changelog for Cldr Calendars v1.25.2 released on July 9th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-25-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec for `Cldr.Calendar.localize/{1,2,3}` again - the return type was being aliased and hence dialyzer was unhappy. Not always, just sometimes.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.25.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.25.1 released on July 7th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-25-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec for `Cldr.Calendar.localize/{1,2,3}` to use the more expansive date/time/datetime types from `Cldr.Calendar`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.25.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.25.0 released on July 7th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-25-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Calendar.Preference.calendar_from_locale/1` when `-u-ca- ` is specified as part of the locale.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* This release provides initial support for partial dates.  Partial dates are those that do not have all of the fields `:year`, `:month`, `:day` and `:calendar`.  Not all functions require all parts of a date. And in some cases, like formatting just the year and the month, it shouldn't be necessary to provide data that has no use.  Of course many functions do require all fields be present - like adding a number of days to a date. In these cases, missing fields will cause an error to be returned. `ex_cldr_dates_times` version 2.19.0 and later take advantage of partial dates when formatting.\n\n* Support `Cldr.Calendar.localize/3` option `era: :variant` to return an alternative localization. For instance, in the `:en` locale, this will return `CE` and `BCE` rather than the default `AD` and `BC`.\n\n* Add `MyApp.Cldr.Calendar.localize/3` that delegates to `Cldr.Calendar.localize/3`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr.Calendars v1.24.2 - Changelog","doc":"This is the changelog for Cldr Calendars v1.24.2 released on June 22nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-24-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix runtime warning about `map.field` notation without parens when calling a function on Elixir 1.17.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.24.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.24.1 released on June 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-24-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Compile on Elixir releases < 1.17. Some code in `Cldr.Calendar` depends on the new `t:Duration.t/0` struct which is only available on Elixir 1.17 or later. Elixir 1.16 is now added to the CI test matrix to ensure no future regression. Thanks to @WernerBuchert for the report. Closes #21.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.24.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.24.0 released on June 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-24-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compiler warnings for Elixir 1.17.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds new calendar callbacks `Calendar.shift_date/4`, `Calendar.shift_time/5` and `Calendar.shift_naive_datetime/8` supported in Elixir 1.17.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr.Calendars v1.23.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.23.1 released on March 1st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-23-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.Calendar.plus/4` consistently applies a default for the `:coerce` option to `Cldr.Calendar.plus/4` and `Cldr.Calendar.minus/4`. The default is `true`. Previously the default for plus/minus months was `true` but the default for years was `false`. Thanks to @linusdm for raising the issue.\n\n* Fix specs for `Cldr.Calendar.localize/{1..3}`. Thanks to @alappe for raising the issue. Closes #15.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.23.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.23.0 released on December 16th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)\n\n**Note that `ex_cldr_calendars` version 1.21.1 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-calendars-v1-23-0"},{"type":"extras","title":"Breaking Change - Changelog","doc":"* `Cldr.Calendar.weeks_in_year/1` now returns a tuple of the form `{weeks_in_year, days_in_last_week}` instead of an integer value. In particular for Gregorian based calendars, the value of `weeks_in_year` will be 53 and the value of `days_last_week` will be either `1` or `2` depending on whether it is a leap year or not.","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `:week` and `:day` to the options for ` .plus/5`. These are in addition to the already existing `:year`, `:quarter` and `:month` options. This addition is primarily to support [tempo](https://github.com/kipcole9/tempo). This enhancement has no affect on the public API in the `Cldr.Calendar` module. The bump in minor release number is to allow for `tempo` to target the appropriate version in a semver compatible manner.\n\n* Adds `Cldr.Calendar.ISO` which is a month-based calendar with weeks that start on Monday and the first week must have at least 4 days of the current year in it. This aligns to the ISO8601 standard and is the month-based counterpart to the week-based `Cldr.Calendar.ISOWeek` calendar already included in `ex_cldr_calendars`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr.Calendars v1.22.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.22.1 released on July 4th 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)\n\n**Note that `ex_cldr_calendars` version 1.21.1 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-calendars-v1-22-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Compatibility with the `Calendar` behaviour changes in Elixir 1.15.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr.Calendars v1.22.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.22.0 released on April 28th 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)\n\n**Note that `ex_cldr_calendars` version 1.21.1 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-calendars-v1-22-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes localization of leap months which are used in lunisolar calendars.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.37.0](https://hex.pm/packages/ex_cldr/2.37.0) which includes data from [CLDR release 43](https://cldr.unicode.org/index/downloads/cldr-43)\n\n* Supports configuring the `:cldr_calendar_name` for a calendar that is defined with the `Cldr.Calendar.Base.{Month, Week}` macros. The options can be `:gregorian` (the default) or `:japanese`. This change supports the new `ex_cldr_calendars_japanese` library.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.21.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.21.0 released on October 24th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-21-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds modified Julian days conversions. Thanks to @polvalente for the PR. Closes #14.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.20.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.20.0 released on September 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-20-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Doctests now reflect the new expression based inspection outputs in Elixir 1.14 for `t:Date.Range.t()`\n\n* Improve the documentation for periods. Thanks to @alappe for the pull requests.\n\n* Add `Cldr.Calendar.date_from_list/2` that takes a keyword list of time units and returns a `t:Date.t/0`\n\n* Add `Cldr.Calendar.date_from_day_of_year/3` that returns a `t:Date.t/0` for the ordinal day of the year.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.19.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.19.0 released on June 9th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-19-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.localize/{1,2}` that converts a date into the calendar associated with the provided locale.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.18.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.18.1 released on June 5th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-18-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `MyApp.Cldr.Calendar.calendar_from_locale/1` was added to the backend compiler module, not the backend module itself and therefore was not visible.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.18.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.18.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-18-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [ex_cldr version 2.26.0](https://hex.pm/packages/ex_cldr/2.26.0) and [ex_cldr_numbers version 2.25.0](https://hex.pm/packages/ex_cldr_numbers/2.25.0) which use atoms for locale names and rbnf locale names. This is consistent with other elements of `t:Cldr.LanguageTag` where atoms are used when the cardinality of the data is fixed and relatively small and strings where the data is free format.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.17.3 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.3 released on January 31st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Kday.nth_kday/3` for when the `kday` is the same as the day of the week of the date.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.17.2 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.2 released on December 26th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `Cldr.Calendar.FiscalYear.calendar_for/2`. Thanks for @DaTrader for the report. Closes #10.\n\n* Use `Cldr.Calendar.date_to_iso_days/1` in preference to `Date.to_gregorian_days/1` since the latter is only available in Elixir 1.11 and later. Thanks to @DaTrader for the report. Closes #11.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.17.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.1 released on November 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Ensure compatibility with Elixir 1.13 by marking the implementations of `Calendar.year_of_era/1` as `@impl true` only on releases earlier than Elixir 1.13. In Elixir 1.13 the callback is `Calendar.year_of_era/3`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.17.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to support [CLDR release 40](https://cldr.unicode.org/index/downloads/cldr-40) via [ex_cldr version 2.24](https://hex.pm/packages/ex_cldr/2.24.0)\n\n* Add support for Chinese, Japanese and Korean [lunisolar calendars](https://github/elixir-cldr/cldr_calendars_lunisolar).\n\n* Adds `Cldr.Calendar.year_of_era/1` that supports eras that might change at any time during a calendar year. This is primarily applicable to the Japanese calendar.\n\n* Add `Cldr.Calendar.Behaviour` that can be `use`d to factor out a lot of calendar boilerplate for many (but not all) calendar types.\n\n* Add `year_of_era/3` as a callback in the `Cldr.Calendar` behaviour. This is required because at least one calendar (the Japanese) can change era on any day of the year.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `day_of_week/{3, 4}` to be compatible with Elixir 1.12 and also earlier versions - and ensure dialyzer passes on consuming applications.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr Calendars v1.17.0-rc.3 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.0-rc.3 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-0-rc-3"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.known_locale_names/1`, call `Cldr.Locale.Loader.known_locale_names/1` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr Calendars v1.17.0-rc.2 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.0-rc.2 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-0-rc-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `day_of_week/{3, 4}` to be compatible with Elixir 1.12 and also earlier versions - and ensure dialyzer passes on consuming applications.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.17.0-rc.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.0-rc.1 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-0-rc-1"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Don't call deprecated `Cldr.Config.get_locale/2`, use `Cldr.Locale.Loader.get_config/2` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr Calendars v1.17.0-rc.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.17.0-rc.0 released on October 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-17-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for Chinese, Japanese and Korean [lunisolar calendars](https://hex.pm/packages/ex_cldr_calendars_lunisolar).\n\n* Adds `Cldr.Calendar.year_of_era/1` that supports eras that might change at any time during a calendar year. This is primarily applicable to the Japanese calendar.\n\n* Add `Cldr.Calendar.Behaviour` that can be `use`d to factor out a lot of calendar boilerplate for many (but not all) calendar types.\n\n* Add `year_of_era/3` as a callback in the `Cldr.Calendar` behaviour. This is required because at least one calendar (the Japanese) can change era on any day of the year.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.16.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.16.0 released on August 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)\n\n**This release requires a minimum of Elixir 1.10 in line with supporting the current release and the two previous releases. Therefore Elixir 1.10, 1.11 and 1.12 are supported.**","ref":"changelog.html#cldr-calendars-v1-16-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Do not require `ex_cldr_numbers` as a dependency.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.15.3 - Changelog","doc":"This is the changelog for Cldr Calendars v1.15.3 released on August 22nd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-15-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes a case when `Cldr.Calendar.Kday.kday_after/1` would return the same date, not the subsequent one.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.15.2 - Changelog","doc":"This is the changelog for Cldr Calendars v1.15.2 released on August 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-15-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix doc errors. Thanks to @maennchen for the report. Doc errors in other `ex_cldr` packages are also updated.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.15.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.15.1 released on August 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-15-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add `Code.ensure_loaded?(Date)` when checking for whether we need to implement `Date.day_of_week/3` or `Date.day_of_week/4` since this changed from earlier Elixir versions.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.15.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.15.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-15-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to [ex_cldr version 2.23.0](https://hex.pm/packages/ex_cldr/2.23.0) which has some changes to the valid territories list requiring a change in some tests. This normally wouldn't require a minor version change but doing so makes it easier to target this library as a dependency.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.14.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.14.1 released on May 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-14-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `@impl` warnings on Elixir 1.12","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.14.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.14.0 released on April 13th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-14-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support creating time-base durations that are negative in direction. Date and DateTime durations must still be positive durations. For example:\n```elixir\n# Create a time-based duration that is negative in direction\niex> {:ok, duration} = Cldr.Calendar.Duration.new ~T[10:00:00.0], ~T[09:00:00.0]\n{:ok,\n %Cldr.Calendar.Duration{\n   day: 0,\n   hour: -1,\n   microsecond: 0,\n   minute: 0,\n   month: 0,\n   second: 0,\n   year: 0\n }}\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.13.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.13.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-13-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fix creating durations from two `Time`s.\n\n* Add support for [CLDR 39](http://cldr.unicode.org/index/downloads/cldr-39) data release","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.12.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.12.1 released on April 7th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-12-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix a bug that prevented durations being created from times (as apposed to dates and datetimes)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.12.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.12.0 released on November 8th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-12-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Rename `Cldr.Calendar.Preference.calendar_for_locale/1` to `Cldr.Calendar.Preference.calendar_from_locale/1`\n\n* Rename `Cldr.Calendar.Preference.calendar_for_territory/1` to `Cldr.Calendar.Preference.calendar_from_territory/1`\n\n* Add `Cldr.Calendar.calendar_from_territory/1`\n\n* Add `Cldr.Calendar.calendar_from_locale/1,2`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.11.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.11.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-11-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add support for [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.10.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.10.1 released on September 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-10-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add a shim for `default_backend/0` that delegates to `Cldr.default_backend/0` or `Cldr.default_backend!/0` depending on `ex_cldr` release. Releases from `2.18.0` use `Cldr.default_backend!/0`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.10.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.10.0 released on August 29th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-10-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Supports upcoming Elixir 1.11.0.  The `Calendar` callback for `day_of_week/3` has been changed to `day_of_week/4` to allow for a different start day of week.  Since `Cldr Calendars` already supports defining calendars with different start days of the week (ie other than Monday), the implementation only supports the `:default` parameter. Thanks to @lostkobrakai for the report. Closes `Cldr Dates Times` issue #17.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.9.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.9.0 released on June 7th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-9-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Calendar.plus/{3,4}` that allows adding a `Cldr.Calendar.Duration` to a `Calendar.date`. Support for adding durations to `datetime`s is not yet available.\n\n* Add support for `datetimes` to `Cldr.Calendar.Duration.new/2`\n\n* Add support for `Date.Range.t` and `CalendarInterval.t` to `Cldr.Calendar.Duration.new/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* More complete test coverage on durations with some additional corner case fixes","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.8.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.8.1 released on June 4th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-8-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix duration calculation when the year and month are the same and the day of the last date is greater than the day of the first date","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.8.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.8.0 released on May 4th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-8-0"},{"type":"extras","title":"Breaking Change (that you might notice but probably won't) - Changelog","doc":"* The `min_days_in_first_week` for the calendar `Cldr.Calendar.Gregorian` is changed to be `1` rather than the previous value of `4`. This only affects week-related processing for the calendar. The reason for the change is that the majority of territories have a preference for `1` for `min_days_in_first_week` so `Cldr.Calendar.Gregorian` more closely aligns to majority expectations.","ref":"changelog.html#breaking-change-that-you-might-notice-but-probably-won-t"},{"type":"extras","title":"Breaking changes (that you shouldn't notice) - Changelog","doc":"* The return result from `Cldr.Calendar.new/3` may return `{:module_already_exists, module}`. It previously returned `{:already_exists, module}`","ref":"changelog.html#breaking-changes-that-you-shouldn-t-notice"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `backend.get_locale/0` instead of `Cldr.get_locale/0` for all options\n\n* Ensure that the default values for a locale's `min_days` and `first_day_of_week` are correctly applied in `Cldr.Calendar.new/3`. Any values passed as options take precedence over those defined for a locale.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Calendar.calendar_for_locale/2` which will create (or return) a gregorian-based calendar configured for the supplied locale. This typically means applying the correct values for `min_days` and `first_day_of_week`. For now all calendars created in this way are Gregorian monthly calendars.\n\n* Add `Cldr.Calendar.Preference.calendar_for_locale/1` which returns the appropriate calendar for a locale based upon locale preferences and configured calendars. Unlike `Cldr.Calendar.calendar_for_locale/2`, this function may return non-Gregorian calendars. For example, for the locale `fa-IR` it will return `Cldr.Calendar.Persian` (if [ex_cldr_calendars_persian](https://hex.pm/packages/ex_cldr_calendars_persian) is configured) because that is the locale preference.\n\n* Add `Cldr.Calendar.Preference.calendar_for_territory/1` provides the same result as `Cldr.Calendar.Preference.calendar_for_locale/2` except that argument is a territory code.\n\n* Add `Cldr.Calendar.Preference.preferences_for_territory/1`\n\n* Add `Cldr.Calendar.validate_calendar/1` which returns `{:ok, calendar}` if the argument is a `Cldr.Calendar` calendar module or `{:error, {exception, reason}}` if not.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.7.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.7.1 released on January 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-7-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix doc link in `MyApp.Cldr.Calendar.strftime_options!/2`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.7.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.7.0 released on January 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Remove call to deprecated `Code.ensure_compiled?/1` in Elixir 1.10","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.6.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.6.0 released on December 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds support for localizing Persian, Coptic and Ethiopic calendar localization. These calendars are published separately but they rely upon localization support from this package.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.5.1 - Changelog","doc":"This is the changelog for Cldr Calendars v1.5.1 released on November 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-5-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Calendar.next/3` and `Cldr.Calendar.previous/3` for months with week-based calendars. Thanks to @bglusman for the report. Closes #3. Note that the use of the `:coerce` option is recommended in most cases.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v1.5.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.5.0 released on November 3rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `MyApp.Cldr.Calendar.strftime_options!/2` to return a keyword list of options that can be applied to `NimbleStrftime.format/3`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.4.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.4.0 released on September 14th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adjusts ` .add/3` to ` .add/5` so that it takes individual date and time elements and not formal structs.  This is consistent with other calendar behaviours.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.3.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.3.0 released on September 1st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"Adds ` .add/3` to add `:quarter` or `:week` to a naive datetime. This adds to the existing support for `:year` and `:month`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.2.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.2.0 released on August 31st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.Duration` to create a duration struct defining the difference between two dates, times or date_times as a calendar difference in years, months, days, hours, minutes, seconds and microseconds. See `Cldr.Calendar.Duration.new/2` and `Cldr.Calendar.Duration.to_string/1`.\n\n* Changes `sigil_d/2` from a function to a macro so that dates are created at compile time","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.1.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.1.0 released on August 30th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds ` .add/3` to add `:year` or `:month` to a naive datetime.  This function supports the library [calendar_interval](https://hex.pm/packages/calendar_interval) allowing intervals to be used with `ex_cldr_calendars`[https://hex.pm/packages/ex_cldr_calendars]. The mid-term objective is to add `add/3` to the `Calendar` behaviour and thereby also simplify the interface to `CalendarInterval`.\n\n* Changes the output of `to_string/1` to consistently use the full name of the calendar module, not an appreviated name.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v1.0.0 - Changelog","doc":"This is the changelog for Cldr Calendars v1.0.0 released on June 16th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v1-0-0"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* The format produced by inspecting a Date (or DateTime or NaiveDateTime) has changed. The parsing of dates in `sigil_d` (the `~d` sigil) has also changed in order to facilitate roundtrip conversions. Previously a date would inspect as (using the NRF calendar) `~d[2019-W01-1]NRF`. It now inspects as `~d[2019-W01-1 NRF]`.  The same approach is used for all calendars.  See the examples in `Cldr.Calendar.Sigils`. This change is applicable to Elixir 1.10 and later.\n\n* The calendar configuration option `:min_days` has been renamed `:min_days_in_first_week`. The configuration option `:day` has been renamed to `:day_of_week` and the option `:month` has been renamed to `:month_of_year`. An exception will be raised if existing calendars are not updated.\n\n* An exception will be raised if a calendar is configured with an unknown option.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Implements `inspect_date/4`, `inspect_datetime/11`, `inspect_naive_datetime/8` and `inspect_time/5` for all `Cldr.Calendar` calendars.  This implementation supports the revised `Inspect` protocol implementation for `Date`, `Time`, `DateTime` and `NaiveDateTime` structs.  The purpose of that change is to allow customer calendars to be inspected. This change is applicable to Elixir 1.10 and later.\n\n* Adds `Cldr.Calendar.week_of_month/1` and `Cldr.Calendar` callback `week_of_month/4` to return the week of a month. The weeks are calculated on the basis of the calendar configuration. As a result, the week of the month, like the week of the year, may be in a different Gregorian year and month compared to the specified date.\n\n* Adds `Cldr.Calendar.weeks_in_year/1` to return the number of weeks in a year.\n\n* Adds a calendar configuration where weeks start on the first day of the year. This configuration is valid only for `:month` based calendars.  The configuration option `day: :first` triggers this behaviour. This configuration can result in the last week of the year being less than 7 days.\n\n* Adds `Cldr.Calendar.inspect/2` that can be used as an `:inspect_fun` option in `Inspect.Opts` for Elixir version 1.9.  It will not be required for Elixir 1.10 and later since [this commit](https://github.com/elixir-lang/elixir/commit/23a68035be96717ca5f8fd20355bdb7bc5ed38f8) introduces `inspect_*` callbacks for `Date`, `Time`, `DateTime` and `NaiveDateTime`. An `:inspect_fun` can be configured in `IEx` by:\n\n```elixir\niex> IEx.configure(inspect: [inspect_fun: &Cldr.Calendar.inspect/2])\n:ok\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Ensure that `Cldr.Calendar` callbacks return a `Calendar.ISO` calendar if called with one (either as part of a date or as a separate argument).\n\n* Ensure the return calendar types of a an Interval are `Calendar.ISO` is the date provided is `Calendar.ISO`\n\n* Fix `Cldr.Calendar.plus/4` for `:months` when the month wraps into the previous year(s)\n\n* Fix `sigil_d` to correctly parse ISO Week dates that have only a single digit day","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v0.9.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.9.0 released on June 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-9-0"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* Depends on Elixir 1.8 and above since it requires recent `Calendar` functionality.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Cldr Calendars v0.8.0 - Changelog","doc":"This is the changelog for Cldr v0.8.0 released on June 8th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds option `:type` to `Cldr.Calendar.localize/3`. This determines the format type to be localized. The valid types are `:format` (the default) or `:stand_alone`.\n\n* Add `Cldr.Calendar.day_periods/2` to support localization of the day periods of a time\n\n* Add `Cldr.Calendar.default_calendar/0`. Returns `Cldr.Calendar.Gregorian`\n\n* Add `Cldr.Calendar.default_cldr_calendar/0`. Returns `:gregorian`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v0.7.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.7.0 released on June 1st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-7-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Moved `year/1`, `quarter/1`, `month/1`, `week/1` and `day/1` to a new module `Cldr.Calendar.Interval`","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.Interval.compare/2` to compare two intervals (date ranges) using [Allen's Interval Algebra](https://en.wikipedia.org/wiki/Allen%27s_interval_algebra) taxonomy.\n\n* Defaults the calendar to `Cldr.Calendar.Gregorian` for `Cldr.Calendar.Interval.year/2`, `Cldr.Calendar.Interval.quarter/3`, `Cldr.Calendar.Interval.month/3`, `Cldr.Calendar.Interval.week/3` and `Cldr.Calendar.Interval.day/3`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v0.6.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.6.0 released on April 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Remove the need for [nimble_csv](https://hex.pm/nimble_csv) as a dependency","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v0.5.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.5.0 released on April 21th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-5-0"},{"type":"extras","title":"Breaking changes - Changelog","doc":"* `Cldr.Calendar.localize/3` for `:days_of_week` now returns a list of 2-tuples that are of the format `{day_of_week, day_name}`.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Calendar.localize/6` which localises numbers as part of a date without parameter checking.  This is considered a private implementation for now.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Calendars v0.4.1 - Changelog","doc":"This is the changelog for Cldr Calendars v0.4.1 released on April 19th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-4-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix calculation of `days_in_month` for the last month in long year of a week-based calendar","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v0.4.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.4.0 released on April 19th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.interval_stream/3` which returns a stream function that when enumerated generates a list of dates with a specified precision of either `:years`, `:quarters`, `:months`, `:weeks` or `:days`. This function has the same arguments and generates the same results as `Cldr.Calendar.interval/3` except it generates the results lazily.\n\n* Adds `:days_of_week` option to `Cldr.Calendar.localize/3` which returns a list of the localized names of the days of the week in calendar order.\n\n* Adds `calendar_base/0` to identify whether the calendar is week or month based.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Calendar.day_of_week/1` for week-based calendars","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v0.3.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.3.0 released on April 16th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.interval/3` which generates an enumerable list of dates with a specified precision of either `:years`, `:quarters`, `:months`, `:weeks` or `:days`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Examples: - Changelog","doc":"```\niex> import Cldr.Calendar.Sigils\nCldr.Calendar.Sigils\n\niex> d = ~d[2019-01-31]\n%Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019}\n\niex> d2 = ~d[2019-05-31]\n%Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019}\n\niex> Cldr.Calendar.interval d, 3, :months\n[\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019},\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019},\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 4, year: 2019}\n]\n\niex> Cldr.Calendar.interval d, d2, :months\n[\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 1, year: 2019},\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 28, month: 2, year: 2019},\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 3, year: 2019},\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 30, month: 4, year: 2019},\n  %Date{calendar: Cldr.Calendar.Gregorian, day: 31, month: 5, year: 2019}\n]\n```","ref":"changelog.html#examples"},{"type":"extras","title":"Cldr Calendars v0.2.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.2.0 released on April 14th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-2-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* All calendars now return `{year, month, day}` tuples from `date_from_iso_days/1`. Previously in some cases they returned a `Date.t`\n\n* `first_day_of_year/1` and `last_day_of_year/1`, `first_gregorian_day_of_year/1` and `last_gregorian_day_of_year/1` now all return a `Date.t` or an error tuple.  Previously the returned result types were inconsistent.\n\n* Remove `first_gregorian_day_of_year/1` and `last_gregorian_day_of_year/1` from `Cldr.Calendar` callbacks.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Calendar.Julian` implementing the Julian calendar. This calendar does not implement `week/2`, `week_of_year/3` or `iso_week_of_year/3`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes calculating negative offsets for months in a week-based calendar.  Thanks to @bglusman. Closes #2.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Calendars v0.1.0 - Changelog","doc":"This is the changelog for Cldr Calendars v0.1.0 released on April 5th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_calendars/tags)","ref":"changelog.html#cldr-calendars-v0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release.  See the README for a description of this project.","ref":"changelog.html#enhancements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}